"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Alert = void 0;
const tslib_1 = require("tslib");
/** @jsx jsx */
const react_1 = require("@emotion/react");
const React = tslib_1.__importStar(require("react"));
const alert_1 = tslib_1.__importDefault(require("@reach/alert"));
const Text_1 = require("./Text");
const IconButton_1 = require("./IconButton");
const prop_types_1 = tslib_1.__importDefault(require("prop-types"));
const Providers_1 = require("./Theme/Providers");
const IconWrapper_1 = require("./IconWrapper");
const Icons_1 = require("./Icons");
const alertIntentions = (theme) => ({
    info: theme.colors.intent.none,
    success: theme.colors.intent.success,
    question: theme.colors.intent.primary,
    danger: theme.colors.intent.danger,
    warning: theme.colors.intent.warning
});
const icons = {
    info: react_1.jsx(Icons_1.IconInfo, null),
    success: react_1.jsx(Icons_1.IconCheckCircle, null),
    warning: react_1.jsx(Icons_1.IconAlertCircle, null),
    danger: react_1.jsx(Icons_1.IconAlertOctagon, null),
    question: react_1.jsx(Icons_1.IconHelpCircle, null)
};
/**
 * Use an alert to inform users of important information.
 * To display an alert in a toast notification, use the toast module.
 */
const Alert = (_a) => {
    var { children, title, id, subtitle, component, elevation = "xs", onRequestClose, intent = "info" } = _a, other = tslib_1.__rest(_a, ["children", "title", "id", "subtitle", "component", "elevation", "onRequestClose", "intent"]);
    const theme = Providers_1.useTheme();
    const intentions = React.useMemo(() => alertIntentions(theme), [theme]);
    const dark = theme.colors.mode === "dark";
    const color = intentions[intent];
    let accent = dark ? color.light : color.base;
    if (dark && intent === "info") {
        accent = color.light;
    }
    const icon = icons[intent];
    const contents = title ? (react_1.jsx("div", { className: "Alert__title", css: { display: "flex", alignItems: "flex-start" } },
        react_1.jsx("div", { css: { flex: "0 0 auto", marginTop: "2px" } },
            react_1.jsx(IconWrapper_1.IconWrapper, { size: "md", color: accent }, icon)),
        react_1.jsx("div", { className: "Alert__text-content", css: { marginLeft: theme.spaces.md } },
            react_1.jsx(Text_1.Text, { className: "Alert__title-text", id: id, css: { margin: 0 }, variant: "h6" }, title),
            subtitle && (react_1.jsx(Text_1.Text, { className: "Alert__title-subtitle", muted: true, css: {
                    fontSize: theme.fontSizes[0]
                } }, subtitle)),
            children))) : (children);
    const Component = component || alert_1.default;
    return (react_1.jsx(Component, Object.assign({ className: "Alert", css: {
            backgroundColor: dark
                ? theme.colors.background.tint1
                : theme.colors.background.default,
            overflow: "hidden",
            position: "relative",
            boxShadow: theme.shadows[elevation],
            borderRadius: theme.radii.md
        } }, other),
        react_1.jsx("div", null,
            react_1.jsx("div", { className: "Alert__bar", css: {
                    width: theme.radii.md,
                    position: "absolute",
                    top: 0,
                    left: 0,
                    bottom: 0,
                    backgroundColor: accent
                } }),
            react_1.jsx("div", { className: "Alert__content", css: {
                    display: "flex",
                    alignItems: "flex-start",
                    padding: `${theme.spaces.md} ${theme.spaces.md}`,
                    paddingRight: onRequestClose ? "3.5rem" : undefined
                } },
                contents,
                onRequestClose && (react_1.jsx(IconButton_1.CloseButton, { css: {
                        marginTop: "-0.45rem",
                        right: theme.spaces.sm,
                        position: "absolute"
                    }, onClick: onRequestClose }))))));
};
exports.Alert = Alert;
exports.Alert.displayName = "Alert";
exports.Alert.propTypes = {
    onRequestClose: prop_types_1.default.func,
    subtitle: prop_types_1.default.string,
    title: prop_types_1.default.string,
    id: prop_types_1.default.oneOfType([prop_types_1.default.string, prop_types_1.default.number]),
    children: prop_types_1.default.node,
    intent: prop_types_1.default.oneOf([
        "info",
        "success",
        "warning",
        "danger",
        "question"
    ]),
    elevation: prop_types_1.default.oneOf(["xs", "sm", "md", "lg", "xl"]),
    component: prop_types_1.default.elementType
};
