"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Avatar = void 0;
const tslib_1 = require("tslib");
/** @jsx jsx */
const react_1 = require("@emotion/react");
const React = tslib_1.__importStar(require("react"));
const visually_hidden_1 = tslib_1.__importDefault(require("@reach/visually-hidden"));
const Text_1 = require("./Text");
const prop_types_1 = tslib_1.__importDefault(require("prop-types"));
const Providers_1 = require("./Theme/Providers");
const sizes = () => ({
    xs: react_1.css({ width: "1.25rem", height: "1.25rem", fontSize: "0.7rem" }),
    sm: react_1.css({ width: "2.02rem", height: "2.02rem", fontSize: "0.875rem" }),
    md: react_1.css({ width: "3.27rem", height: "3.27rem", fontSize: "1.41rem" }),
    lg: react_1.css({ width: "5.29rem", height: "5.29rem", fontSize: "2.29rem" }),
    xl: react_1.css({ width: "8.57rem", height: "8.57rem", fontSize: "3.70rem" })
});
/**
 * Display a profile image to represent a user. Initials can be shown as a fallback
 */
const Avatar = (_a) => {
    var { src, name, size = "md", srcSet } = _a, other = tslib_1.__rest(_a, ["src", "name", "size", "srcSet"]);
    const theme = Providers_1.useTheme();
    const dark = theme.colors.mode === "dark";
    const colors = Object.keys(theme.colors.palette);
    const img = src || srcSet;
    let initials = getInitials(name);
    if (size === "xs")
        initials = initials.substring(0, 1);
    const color = colors[Math.abs(makeHash(name)) % colors.length];
    const [error, setError] = React.useState(false);
    function onError() {
        setError(true);
    }
    return (react_1.jsx("div", Object.assign({ css: [
            {
                display: "flex",
                alignItems: "center",
                flex: "0 0 auto",
                justifyContent: "center",
                borderRadius: "50%",
                backgroundColor: img
                    ? theme.colors.background.tint2
                    : theme.colors.palette[color][dark ? "light" : "base"]
            },
            sizes()[size]
        ] }, other), img && !error ? (react_1.jsx("img", { alt: name, src: src, srcSet: srcSet, onError: onError, css: {
            width: "100%",
            height: "100%",
            objectFit: "cover",
            borderRadius: "50%",
            display: "block"
        } })) : (react_1.jsx("div", null,
        react_1.jsx(visually_hidden_1.default, null, name),
        react_1.jsx(Text_1.Text, { css: {
                fontWeight: size === "xs" ? 500 : 400,
                fontSize: "inherit",
                color: dark ? "rgba(0,0,0,0.75)" : "white"
            } }, initials)))));
};
exports.Avatar = Avatar;
exports.Avatar.propTypes = {
    src: prop_types_1.default.string,
    name: prop_types_1.default.string,
    size: prop_types_1.default.oneOf(["xs", "sm", "md", "lg", "xl"]),
    srcSet: prop_types_1.default.string
};
function getInitials(name = "?") {
    return name
        .replace(/\s+/, " ")
        .split(" ")
        .slice(0, 2)
        .map(v => v[0])
        .join("")
        .toUpperCase();
}
function makeHash(name = "?") {
    var hash = 0, i, chr;
    if (name.length === 0)
        return hash;
    for (i = 0; i < name.length; i++) {
        chr = name.charCodeAt(i);
        hash = (hash << 5) - hash + chr;
        hash |= 0; // Convert to 32bit integer
    }
    return hash;
}
