"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.TestRenderLoad = exports.LazyToggleViewer = exports.usePrevious = exports.Collapse = exports.AnimateCollapse = exports.useCollapse = void 0;
const tslib_1 = require("tslib");
/** @jsx jsx */
const react_1 = require("@emotion/react");
const React = tslib_1.__importStar(require("react"));
const react_spring_1 = require("react-spring");
const prop_types_1 = tslib_1.__importDefault(require("prop-types"));
const use_measure_1 = require("./Hooks/use-measure");
const use_uid_1 = require("./Hooks/use-uid");
const Text_1 = require("./Text");
function useCollapse(defaultShow = false, press = false) {
    const [show, setShow] = React.useState(defaultShow);
    const id = use_uid_1.useUid();
    function onClick() {
        setShow(!show);
    }
    React.useEffect(() => {
        setShow(defaultShow);
    }, [defaultShow]);
    return {
        show,
        setShow,
        id,
        buttonProps: {
            onClick: press ? undefined : onClick,
            onPress: press ? onClick : undefined,
            "aria-controls": id,
            "aria-expanded": show ? true : false
        },
        collapseProps: {
            id,
            show
        }
    };
}
exports.useCollapse = useCollapse;
/**
 * Hide and reveal content with an animation. Supports dynamic
 * heights.
 */
const AnimateCollapse = (_a) => {
    var { children, id, show, divStyle } = _a, other = tslib_1.__rest(_a, ["children", "id", "show", "divStyle"]);
    const ref = React.useRef(null);
    const { bounds } = use_measure_1.useMeasure(ref);
    const prevShow = usePrevious(show);
    //高度 动画副作用，导致计算问题？ 旧的to: { height: show ? bounds.height : 0 },
    //这个height实际是一个对象的。  const { animationObj } = useSpring ；注意两个height不是一个东西。
    //这里useSpring({）的参数 实际是初始化用的，后面输出的对象height.value实际是动画编制的起始数值，而不是目标数值。
    //[问题！] 这里的useSpring（）没有处理内部DIV高度变化的副作用；打印机场景div高度会缩放调整，应该被缩小的<animated.div却没有被缩小。
    const { height } = react_spring_1.useSpring({
        from: { height: 0 },
        to: { height: show ? bounds.height : 0 },
        immediate: prevShow !== null && prevShow === show
    });
    //实际打印预览会捕获3次的render这里，Collapse-捕获height=，前面2次纸张缩放调整，缩小了，div就会变矮化，后面第三次却是屏幕的。
    //只好先预留大一点的高度。 有待改进。动画可能切割打印。
    const dynamicHeight = (bounds.height > (height && height.value)) ? (bounds.height) : (height && height.value) > 0 ? (height && height.value) : undefined;
    return (react_1.jsx("div", { css: [
            {
                height: show ? dynamicHeight : 0,
                ["@media not print"]: {
                    display: show ? undefined : 'none',
                },
                ["@media print"]: {
                    overflow: "hidden",
                },
            },
        ] },
        react_1.jsx(react_spring_1.animated.div, Object.assign({ id: id, style: { height }, css: {
                willChange: "height, opacity",
            } }, other),
            react_1.jsx("div", { ref: ref, css: divStyle }, children))));
};
exports.AnimateCollapse = AnimateCollapse;
/**
 * Hide and reveal content with an animation. Supports dynamic heights.
 * 针对两种方式取舍display:'none', 和 show&& (<div>{children}</div>)比较，还是逻辑隐藏更好，若遇到耗时子组件时表现更好。
 */
const Collapse = (_a) => {
    var { children, id, show, divStyle, noAnimated = false } = _a, other = tslib_1.__rest(_a, ["children", "id", "show", "divStyle", "noAnimated"]);
    return (react_1.jsx(React.Fragment, null, noAnimated ? (react_1.jsx("div", Object.assign({ id: id, "aria-hidden": !show, css: {
            display: show ? undefined : 'none',
            overflow: "hidden",
        } }, other),
        react_1.jsx(exports.LazyToggleViewer, { show: show, css: divStyle }, children)))
        :
            (react_1.jsx(exports.AnimateCollapse, { id: id, show: show, divStyle: divStyle }, children))));
};
exports.Collapse = Collapse;
exports.Collapse.propTypes = {
    children: prop_types_1.default.node,
    id: prop_types_1.default.string.isRequired,
    show: prop_types_1.default.bool.isRequired
};
function usePrevious(value) {
    const ref = React.useRef(null);
    React.useEffect(() => {
        ref.current = value;
    }, [value]);
    return ref.current;
}
exports.usePrevious = usePrevious;
//切换隐藏显示得内容： 初始化show=false情形=启动懒加载。是取长补短的模式。
//若放在逻辑&&方式{show&&()}的组件下或路由后再进入呈现的子组件，就失去效果，父组件被要求重新渲染！就等于树的根节点决定枝条节点命运。
//这样来看该组件放在层级太低的组件位置，可能没有意义，要搞就得放在较高组件层次的位置上。路由RouterLink本身就是逻辑&&方式的。
const LazyToggleViewer = (_a) => {
    var { show, children } = _a, other = tslib_1.__rest(_a, ["show", "children"]);
    const [mounted, setMounted] = React.useState(false);
    if (!mounted) {
        if (show)
            setMounted(true);
        //这里反正底下组件还未加载，可以这么做
        return null;
    }
    return (react_1.jsx("div", Object.assign({ css: { display: show ? undefined : 'none' } }, other), children));
};
exports.LazyToggleViewer = LazyToggleViewer;
exports.LazyToggleViewer.propTypes = {
    children: prop_types_1.default.node,
    show: prop_types_1.default.bool.isRequired
};
//性能测试专用的。
const TestRenderLoad = (_a) => {
    var { loop = 3000, num = 4, txt = '针对渲染次数做优化，性能测试专用的！' } = _a, other = tslib_1.__rest(_a, ["loop", "num", "txt"]);
    console.log(txt);
    return (react_1.jsx("div", Object.assign({ css: { display: 'none' } }, other), Array.from(new Array(loop)).map((a, i) => {
        return react_1.jsx(Text_1.Text, { key: i }, Array.from(new Array(num)).map((a, i) => { return react_1.jsx(Text_1.Text, { key: i }, txt); }));
    })));
};
exports.TestRenderLoad = TestRenderLoad;
