"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ComboBoxOptionText = exports.ComboBoxOption = exports.ComboBoxList = exports.ComboBoxInput = exports.ComboBox = exports.ComboBoxContext = void 0;
const tslib_1 = require("tslib");
/** @jsx jsx */
const react_1 = require("@emotion/react");
const React = tslib_1.__importStar(require("react"));
const use_positioner_1 = require("./Hooks/use-positioner");
const use_uid_1 = require("./Hooks/use-uid");
const compose_bind_1 = require("./Hooks/compose-bind");
const Providers_1 = require("./Theme/Providers");
const Text_1 = require("./Text");
const Touchable_1 = require("./Touchable");
const use_measure_1 = require("./Hooks/use-measure");
const Layer_1 = require("./Layer");
const react_highlight_words_1 = tslib_1.__importDefault(require("react-highlight-words"));
const Form_1 = require("./Form");
exports.ComboBoxContext = React.createContext(null);
const ComboBox = ({ children, onSelect, autocomplete = false, query, onQueryChange, topDivStyle }) => {
    const inputRef = React.useRef(null);
    const listRef = React.useRef(null);
    const listId = `list${use_uid_1.useUid()}`;
    const options = React.useRef([]);
    const position = use_positioner_1.usePositioner({
        modifiers: {
            flip: {
                enabled: false
            }
        }
    });
    const [expanded, setExpanded] = React.useState(false);
    const [selected, setSelected] = React.useState(null);
    const inputSize = use_measure_1.useMeasure(inputRef);
    /**
     * Handle input change
     */
    const onInputChange = React.useCallback((e) => {
        // potentially show popover
        setSelected(null);
        if (!expanded) {
            setExpanded(true);
        }
        onQueryChange(e.target.value);
    }, [expanded]);
    /**
     * Escape key pressed
     */
    const onEscape = React.useCallback(() => {
        setExpanded(false);
        setSelected(null);
    }, []);
    /**
     * Enter pressed or item clicked
     */
    const onItemSelect = React.useCallback(() => {
        // call the parent with the selected value?
        setExpanded(false);
        onSelect && onSelect(selected);
        setSelected(null);
    }, [selected]);
    /**
     * Get the currently active option index
     * */
    const getSelectedIndex = React.useCallback(() => {
        if (!selected)
            return -1;
        return options.current.indexOf(selected || "");
    }, [options, selected]);
    /**
     * Arrow up pressed
     */
    const onArrowUp = React.useCallback(() => {
        const opts = options.current;
        const i = getSelectedIndex();
        // on input? cycle to bottom
        if (i === -1) {
            setSelected(opts[opts.length - 1]);
            // select prev
        }
        else {
            setSelected(opts[i - 1]);
        }
    }, [getSelectedIndex]);
    /**
     * Arrow down pressed
     */
    const onArrowDown = React.useCallback(() => {
        const opts = options.current;
        const i = getSelectedIndex();
        // if last, cycle to first
        if (i + 1 === opts.length) {
            setSelected(opts[0]);
            // or next
        }
        else {
            setSelected(opts[i + 1]);
        }
    }, [getSelectedIndex, selected]);
    /**
     * Handle keydown events
     */
    const onKeyDown = React.useCallback((e) => {
        switch (e.key) {
            case "ArrowUp":
                e.preventDefault();
                onArrowUp();
                break;
            case "ArrowDown":
                e.preventDefault();
                onArrowDown();
                break;
            case "Escape":
                e.preventDefault();
                onEscape();
                break;
            case "Enter":
                e.preventDefault();
                onItemSelect();
                break;
        }
    }, [onArrowDown, onArrowUp, onEscape, onItemSelect]);
    /**
     * Handle blur events
     */
    const handleBlur = React.useCallback(() => {
        requestAnimationFrame(() => {
            const focusedElement = document.activeElement;
            const list = listRef.current;
            if (focusedElement == inputRef.current || focusedElement == list) {
                // ignore
                return;
            }
            // ignore if our popover contains the focused element
            if (list && list.contains(focusedElement)) {
                return;
            }
            // hide popover
            setExpanded(false);
            setSelected(null);
        });
    }, []);
    /**
     * handle input focus
     */
    const handleFocus = React.useCallback(() => {
        setExpanded(true);
    }, []);
    /**
     * Handle item clicks
     */
    const handleOptionSelect = React.useCallback((value) => {
        onSelect && onSelect(value);
        setExpanded(false);
        setSelected(null);
    }, []);
    /**
     * Make a unique hash for list + option
     */
    const makeHash = React.useCallback((i) => {
        return listId + i;
    }, [listId]);
    return (react_1.jsx(exports.ComboBoxContext.Provider, { value: {
            listId,
            inputRef,
            listRef,
            options,
            onInputChange,
            selected,
            onKeyDown,
            handleBlur,
            handleFocus,
            handleOptionSelect,
            position,
            makeHash,
            expanded,
            inputSize: inputSize.bounds,
            query,
            autocomplete,
            topDivStyle,
        } }, children));
};
exports.ComboBox = ComboBox;
//分解配套的模式ComboBoxInput必需加到ComboBox底下的，ComboBox本身没有实际的div元素,靠context管理传递参数。
const ComboBoxInput = (_a) => {
    var { component: Component = Form_1.InputBase } = _a, other = tslib_1.__rest(_a, ["component"]);
    const context = React.useContext(exports.ComboBoxContext);
    const [localValue, setLocalValue] = React.useState("");
    if (!context) {
        throw new Error("ComboBoxInput must be wrapped in a ComboBox component");
    }
    //这里topDivStyle样式从上级组件ComboBox以共享同一个context模式传递的，算是第二次传递。
    const { onKeyDown, makeHash, selected, position, handleBlur, query, autocomplete, handleFocus, onInputChange, listId, inputRef, topDivStyle } = context;
    /** support autocomplete on selection */
    React.useEffect(() => {
        if (!autocomplete) {
            return;
        }
        if (selected) {
            setLocalValue(selected);
        }
        else {
            setLocalValue("");
        }
    }, [selected, autocomplete]);
    return (react_1.jsx(Component, Object.assign({ id: listId, onKeyDown: onKeyDown, onChange: onInputChange, onBlur: handleBlur, onFocus: handleFocus, "aria-controls": listId, autoComplete: "off", value: localValue || query, "aria-readonly": true, "aria-autocomplete": "list", role: "textbox", css: [
            {},
            topDivStyle
        ], "aria-activedescendant": selected ? makeHash(selected) : undefined }, compose_bind_1.safeBind({
        ref: inputRef
    }, {
        ref: position.target.ref
    }, other))));
};
exports.ComboBoxInput = ComboBoxInput;
const ComboBoxList = (_a) => {
    var { children, autoHide = true } = _a, other = tslib_1.__rest(_a, ["children", "autoHide"]);
    const context = React.useContext(exports.ComboBoxContext);
    const theme = Providers_1.useTheme();
    if (!context) {
        throw new Error("ComboBoxInput must be wrapped in a ComboBox component");
    }
    const { inputSize, expanded, listId, handleBlur, listRef, position, options } = context;
    React.useLayoutEffect(() => {
        options.current = [];
        return () => {
            options.current = [];
        };
    });
    return (react_1.jsx(React.Fragment, null, (expanded || !autoHide) && (react_1.jsx(Layer_1.Layer, Object.assign({ tabIndex: -1, elevation: "sm", key: "1", style: position.popover.style, "data-placement": position.popover.placement, id: listId, role: "listbox", onBlur: handleBlur, className: "ComboBoxList", css: {
            overflow: "hidden",
            borderRadius: theme.radii.sm,
            outline: "none",
            width: inputSize.width +
                inputSize.left +
                (inputSize.right - inputSize.width) +
                "px",
            margin: 0,
            padding: 0,
            zIndex: theme.zIndices.overlay,
        } }, compose_bind_1.safeBind({
        ref: listRef
    }, {
        ref: position.popover.ref
    }, other)),
        children,
        react_1.jsx("div", { ref: position.arrow.ref, style: position.arrow.style })))));
};
exports.ComboBoxList = ComboBoxList;
const ComboBoxOption = (_a) => {
    var { value, children } = _a, other = tslib_1.__rest(_a, ["value", "children"]);
    const context = React.useContext(exports.ComboBoxContext);
    const theme = Providers_1.useTheme();
    if (!context) {
        throw new Error("ComboBoxInput must be wrapped in a ComboBox component");
    }
    const { makeHash, handleOptionSelect, options, selected } = context;
    React.useEffect(() => {
        if (options.current) {
            options.current.push(value);
        }
    });
    const isSelected = selected === value;
    const onClick = React.useCallback(() => {
        handleOptionSelect(value);
    }, [value]);
    return (react_1.jsx(Touchable_1.Touchable, Object.assign({ tabIndex: -1, id: makeHash(value), role: "option", component: "li", onPress: onClick, "aria-selected": isSelected ? "true" : "false", css: {
            outline: "none",
            width: "100%",
            boxSizing: "border-box",
            display: "block",
            listStyleType: "none",
            margin: 0,
            padding: `0.5rem 0.75rem`,
            cursor: "pointer",
            background: isSelected ? theme.colors.background.tint1 : "none",
            "&.Touchable--hover": {
                background: theme.colors.background.tint1
            },
            "&.Touchable--active": {
                background: theme.colors.background.tint2
            }
        } }, other), children || react_1.jsx(exports.ComboBoxOptionText, { value: value })));
};
exports.ComboBoxOption = ComboBoxOption;
const ComboBoxOptionText = (_a) => {
    var { value } = _a, other = tslib_1.__rest(_a, ["value"]);
    const context = React.useContext(exports.ComboBoxContext);
    const theme = Providers_1.useTheme();
    if (!context) {
        throw new Error("ComboBoxInput must be wrapped in a ComboBox component");
    }
    const { query } = context;
    return (react_1.jsx(Text_1.Text, Object.assign({ className: "ComboBoxOptionText", css: { fontWeight: theme.fontWeights.heading } }, other),
        react_1.jsx(react_highlight_words_1.default, { highlightStyle: {
                color: theme.colors.text.selected,
                background: "transparent"
            }, className: "ComboBoxOptionText__Highlighter", searchWords: [query], autoEscape: true, textToHighlight: value })));
};
exports.ComboBoxOptionText = ComboBoxOptionText;
