"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DialogHeader = exports.Dialog = void 0;
const tslib_1 = require("tslib");
/** @jsx jsx */
const react_1 = require("@emotion/react");
const React = tslib_1.__importStar(require("react"));
const Text_1 = require("./Text");
const IconButton_1 = require("./IconButton");
const react_spring_1 = require("react-spring");
const Overlay_1 = require("./Overlay");
const use_focus_trap_1 = require("./Hooks/use-focus-trap");
const prop_types_1 = tslib_1.__importDefault(require("prop-types"));
const use_scroll_lock_1 = tslib_1.__importDefault(require("use-scroll-lock"));
const Providers_1 = require("./Theme/Providers");
/**
 * A dialog is useful for displaying infomation that
 * commands the user's attention.
 */
const Dialog = (_a) => {
    var { isOpen, onRequestClose, mobileFullscreen, title, children } = _a, other = tslib_1.__rest(_a, ["isOpen", "onRequestClose", "mobileFullscreen", "title", "children"]);
    const theme = Providers_1.useTheme();
    // [TransitionFn<Item, State & object>, SpringStartFn<State>, SpringStopFn<State>]
    const transitions = react_spring_1.useTransition(isOpen, {
        from: { opacity: 0, transform: "scale(0.9)" },
        enter: { opacity: 1, transform: "scale(1)" },
        leave: { opacity: 0, transform: "scale(0.9)" },
        config: { mass: 1, tension: 185, friction: 26 }
    });
    const scrollableRef = React.useRef(null);
    const ref = React.useRef(null);
    use_focus_trap_1.useFocusElement(ref, isOpen);
    use_scroll_lock_1.default(isOpen, scrollableRef);
    return (react_1.jsx(React.Fragment, null,
        react_1.jsx(Overlay_1.Overlay, { onRequestClose: onRequestClose, isOpen: isOpen },
            react_1.jsx(React.Fragment, null, transitions((style, item) => {
                return (item && react_1.jsx(react_spring_1.animated.div, Object.assign({ key: 1, className: "Dialog", "aria-modal": "true", ref: ref, tabIndex: -1, onClick: (e) => {
                        e.stopPropagation();
                    }, style: {
                        opacity: style.opacity,
                        transform: style.transform
                    }, css: [
                        {
                            zIndex: theme.zIndices.modal,
                            background: theme.colors.background.default,
                            boxShadow: theme.shadows.md,
                            borderRadius: theme.radii.lg,
                            margin: "16px",
                            width: "calc(100% - 32px)",
                            outline: "none",
                            [theme.mediaQueries.md]: {
                                maxWidth: "500px",
                                margin: "30px auto"
                            },
                            [theme.mediaQueries.lg]: {
                                maxWidth: "650px",
                                margin: "30px auto"
                            }
                        },
                        mobileFullscreen && {
                            maxWidth: "none",
                            margin: 0,
                            width: "100vw",
                            height: "100vh",
                            borderRadius: 0,
                            boxShadow: "none",
                            [theme.mediaQueries.md]: {
                                maxWidth: "500px",
                                margin: "30px auto",
                                height: "auto",
                                boxShadow: theme.shadows.md,
                                borderRadius: theme.radii.lg,
                                width: "calc(100% - 32px)"
                            }
                        }
                    ] }, other),
                    react_1.jsx(React.Fragment, null,
                        title && (react_1.jsx(exports.DialogHeader, { className: "Dialog__header", css: {
                                display: "flex",
                                justifyContent: "space-between",
                                alignItems: "center",
                                padding: `${theme.spaces.lg} ${theme.spaces.lg} 0 ${theme.spaces.lg}`
                            }, title: title, onRequestClose: onRequestClose })),
                        react_1.jsx("div", { ref: scrollableRef }, children))));
            })))));
};
exports.Dialog = Dialog;
exports.Dialog.propTypes = {
    isOpen: prop_types_1.default.bool.isRequired,
    onRequestClose: prop_types_1.default.func.isRequired,
    title: prop_types_1.default.string,
    mobileFullscreen: prop_types_1.default.bool,
    children: prop_types_1.default.node
};
const DialogHeader = (_a) => {
    var { title, onRequestClose } = _a, other = tslib_1.__rest(_a, ["title", "onRequestClose"]);
    return (react_1.jsx("div", Object.assign({}, other),
        react_1.jsx(Text_1.Text, { wrap: false, variant: "h4" }, title),
        onRequestClose && react_1.jsx(IconButton_1.CloseButton, { onClick: onRequestClose })));
};
exports.DialogHeader = DialogHeader;
exports.DialogHeader.propTypes = {
    title: prop_types_1.default.string.isRequired,
    onRequestClose: prop_types_1.default.func
};
