"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Embed = exports.getEmbedStyles = void 0;
const tslib_1 = require("tslib");
/** @jsx jsx */
const react_1 = require("@emotion/react");
const prop_types_1 = tslib_1.__importDefault(require("prop-types"));
function getEmbedStyles(width, height) {
    const percentage = (height / width) * 100;
    return react_1.css `
    position: relative;
    display: block;
    width: 100%;
    padding: 0;
    & > * {
      position: absolute;
      top: 0;
      bottom: 0;
      left: 0;
      width: 100%;
      height: 100%;
      border: 0;
    }
    ::before {
      display: block;
      content: "";
      padding-top: ${percentage}%;
    }
  `;
}
exports.getEmbedStyles = getEmbedStyles;
/**
 * The Embed component maintains the provided aspect ratio determined
 * by the width and height props. It's useful for avoiding content shifting on image
 * loading.
 */
const Embed = (_a) => {
    var { width = 4, height = 3 } = _a, other = tslib_1.__rest(_a, ["width", "height"]);
    return react_1.jsx("div", Object.assign({ css: getEmbedStyles(width, height) }, other));
};
exports.Embed = Embed;
exports.Embed.propTypes = {
    width: prop_types_1.default.number,
    height: prop_types_1.default.number
};
