"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.safeBind = void 0;
const merge_refs_1 = require("./merge-refs");
const safeBind = (...bindGroups) => {
    const groupedFns = {};
    const fns = {};
    const refs = [];
    function propFnFactory(name) {
        return (e, ...args) => {
            const callbacks = groupedFns[name];
            if (!e.defaultPrevented) {
                callbacks.forEach(cb => cb(e, ...args));
            }
        };
    }
    bindGroups.forEach(bind => {
        Object.entries(bind).forEach(([key, value]) => {
            if (key === "ref") {
                refs.push(value);
                return;
            }
            if (typeof value !== "function") {
                fns[key] = value;
                return;
            }
            if (!groupedFns[key]) {
                groupedFns[key] = [];
            }
            groupedFns[key].push(value);
            fns[key] = propFnFactory(key);
        });
    });
    if (refs.length > 0) {
        fns.ref = merge_refs_1.mergeRefs(...refs);
    }
    return fns;
};
exports.safeBind = safeBind;
