"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useHideBody = void 0;
const tslib_1 = require("tslib");
const React = tslib_1.__importStar(require("react"));
function useHideBody(showing) {
    const overlayRef = React.useRef(null);
    const returnRef = React.useRef(null);
    function setElementsHidden() {
        const els = document.querySelectorAll("body > *");
        let originals = [];
        els.forEach(el => {
            if (el.contains(overlayRef.current)) {
                return;
            }
            const hidden = el.getAttribute("aria-hidden");
            if (hidden !== "true") {
                originals.push({ el, attr: hidden });
                el.setAttribute("aria-hidden", "true");
            }
        });
        return () => {
            originals.forEach(({ el, attr }) => {
                attr === null
                    ? el.removeAttribute("aria-hidden")
                    : el.setAttribute("aria-hidden", attr);
            });
        };
    }
    React.useEffect(() => {
        if (showing) {
            returnRef.current = setElementsHidden();
        }
        else if (returnRef.current) {
            returnRef.current();
        }
    }, [showing]);
    // unmount
    React.useEffect(() => {
        if (returnRef.current) {
            returnRef.current();
        }
    }, []);
    return {
        bind: { ref: overlayRef }
    };
}
exports.useHideBody = useHideBody;
