"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useMeasure = void 0;
const tslib_1 = require("tslib");
const React = tslib_1.__importStar(require("react"));
const resize_observer_polyfill_1 = tslib_1.__importDefault(require("resize-observer-polyfill"));
const use_callback_ref_1 = require("./use-callback-ref");
function useMeasure(ref) {
    const [element, attachRef] = use_callback_ref_1.useCallbackRef();
    // unsure if this would be better defaulting to null. I think
    // in practice it's easier to just use default values of 0
    const [bounds, setBounds] = React.useState({
        left: 0,
        height: 0,
        top: 0,
        width: 0,
        bottom: 0,
        x: 0,
        y: 0,
        right: 0
    });
    // bind resize handler
    React.useEffect(() => {
        function onResize([entry]) {
            setBounds(entry.contentRect);
        }
        const observer = new resize_observer_polyfill_1.default(onResize);
        if (element && element.current) {
            observer.observe(element.current);
        }
        return () => {
            observer.disconnect();
        };
    }, [element]);
    // attach our ref
    React.useEffect(() => {
        attachRef(ref);
    }, []);
    return { bounds };
}
exports.useMeasure = useMeasure;
