"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.usePositioner = void 0;
const tslib_1 = require("tslib");
const popper_js_1 = tslib_1.__importDefault(require("popper.js"));
const React = tslib_1.__importStar(require("react"));
const use_callback_ref_1 = require("./use-callback-ref");
const defaultStyle = {
    position: "absolute",
    top: 0,
    left: 0,
    opacity: 0,
    pointerEvents: "none"
};
/**
 * Position an element relative to another
 */
function usePositioner({ placement: defaultPlacement = "bottom", positionFixed = false, eventsEnabled = true, modifiers = {} } = {}) {
    const [target, attachTarget] = use_callback_ref_1.useCallbackRef();
    const [popover, attachPopover] = use_callback_ref_1.useCallbackRef();
    const [arrow, attachArrow] = use_callback_ref_1.useCallbackRef();
    // positions
    const [popperStyle, setPopperStyle] = React.useState(defaultStyle);
    const [arrowStyle, setArrowStyle] = React.useState({});
    const [placement, setPlacement] = React.useState(null);
    React.useEffect(() => {
        if (!target || !popover) {
            return;
        }
        function updatePopperState(data) {
            const { styles, arrowStyles, placement: place } = data;
            setPopperStyle(styles);
            setArrowStyle(arrowStyles);
            setPlacement(place);
            return data;
        }
        //  @ts-ignore
        const pop = new popper_js_1.default(target, popover, {
            placement: defaultPlacement,
            positionFixed,
            eventsEnabled,
            modifiers: Object.assign(Object.assign({}, modifiers), { arrow: Object.assign(Object.assign({}, (modifiers && modifiers.arrow)), { enabled: true, element: arrow }), applyStyle: { enabled: false }, updateStateModifier: {
                    enabled: true,
                    order: 900,
                    fn: updatePopperState
                } })
        });
        return () => {
            if (pop) {
                pop.destroy();
            }
        };
    }, [target, popover, defaultPlacement, eventsEnabled, positionFixed, arrow]);
    return {
        target: {
            ref: attachTarget,
            node: target
        },
        popover: {
            node: popover,
            style: popperStyle,
            ref: attachPopover,
            placement
        },
        arrow: {
            node: arrow,
            style: arrowStyle,
            ref: attachArrow
        }
    };
}
exports.usePositioner = usePositioner;
