"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.CloseButton = exports.IconButton = void 0;
const tslib_1 = require("tslib");
/** @jsx jsx */
const react_1 = require("@emotion/react");
const React = tslib_1.__importStar(require("react"));
const Button_1 = require("./Button");
const visually_hidden_1 = tslib_1.__importDefault(require("@reach/visually-hidden"));
const prop_types_1 = tslib_1.__importDefault(require("prop-types"));
const IconWrapper_1 = require("./IconWrapper");
const Icons_1 = require("./Icons");
const Providers_1 = require("./Theme/Providers");
/**
 * A component which composes Button and Icon to provide
 * interactive icon elements.
 */
exports.IconButton = React.forwardRef((_a, ref) => {
    var { label, size = "md", icon, onPress, color = "currentColor" } = _a, other = tslib_1.__rest(_a, ["label", "size", "icon", "onPress", "color"]);
    const theme = Providers_1.useTheme();
    return (react_1.jsx(Button_1.Button, Object.assign({ ref: ref, size: size, css: {
            padding: 0,
            [theme.mediaQueries.sm]: {
                padding: 0,
            },
            [theme.mediaQueries.lg]: {
                padding: 0,
            },
            width: Button_1.getHeight(size)
        }, onPress: onPress }, other),
        react_1.jsx(visually_hidden_1.default, null, label),
        react_1.jsx(IconWrapper_1.IconWrapper, { color: color, size: size }, icon)));
});
exports.IconButton.displayName = "IconButton";
exports.IconButton.propTypes = {
    icon: prop_types_1.default.node.isRequired,
    color: prop_types_1.default.string,
    label: prop_types_1.default.string.isRequired,
    variant: prop_types_1.default.oneOf(["outline", "default", "ghost"]),
    size: prop_types_1.default.oneOf(["xs", "sm", "md", "lg", "xl"])
};
const CloseButton = (_a) => {
    var { label = "Close" } = _a, other = tslib_1.__rest(_a, ["label"]);
    return (react_1.jsx(exports.IconButton, Object.assign({ variant: "ghost", label: label, icon: react_1.jsx(Icons_1.IconX, null) }, other)));
};
exports.CloseButton = CloseButton;
exports.CloseButton.propTypes = {
    label: prop_types_1.default.string,
    color: prop_types_1.default.string,
    variant: prop_types_1.default.oneOf(["outline", "default", "ghost"]),
    size: prop_types_1.default.oneOf(["xs", "sm", "md", "lg", "xl"])
};
