"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ListSection = exports.ListItem = exports.List = void 0;
const tslib_1 = require("tslib");
/** @jsx jsx */
const react_1 = require("@emotion/react");
const Text_1 = require("./Text");
const prop_types_1 = tslib_1.__importDefault(require("prop-types"));
const Menu_1 = require("./Menu");
const Providers_1 = require("./Theme/Providers");
const noop_1 = require("./misc/noop");
const touchable_hook_1 = require("touchable-hook");
const compose_bind_1 = require("./Hooks/compose-bind");
const List = (_a) => {
    var { children } = _a, other = tslib_1.__rest(_a, ["children"]);
    return react_1.jsx("nav", Object.assign({}, other), children);
};
exports.List = List;
exports.List.propTypes = {
    children: prop_types_1.default.node
};
const ListItem = (_a) => {
    var { primary, secondary, contentBefore, interactive = true, children, wrap = true, contentAfter, onPress = noop_1.noOp, component: Component = "div" } = _a, other = tslib_1.__rest(_a, ["primary", "secondary", "contentBefore", "interactive", "children", "wrap", "contentAfter", "onPress", "component"]);
    const interactiveProps = interactive
        ? {
            role: "button",
            tabIndex: 0
        }
        : {};
    const isLink = other.to || other.href;
    const { bind, hover, active } = touchable_hook_1.useTouchable({
        onPress,
        behavior: isLink ? "link" : "button"
    });
    const theme = Providers_1.useTheme();
    return (react_1.jsx(Component, Object.assign({ className: "ListItem", css: [
            {
                display: "block",
                textDecoration: "none",
                outline: "none",
                padding: theme.spaces.md,
                background: "transparent",
                WebkitTapHighlightColor: "transparent",
                transition: "background 0.07s ease",
                [theme.mediaQueries.lg]: {
                    paddingLeft: theme.spaces.lg,
                    paddingRight: theme.spaces.lg
                },
                ":last-child": {
                    borderBottom: "none"
                }
            },
            interactive && {
                cursor: "pointer",
                ":focus": {
                    boxShadow: `inset 0 0 3px ${theme.colors.text.selected}`
                },
                ":focus:not([data-focus-visible-added])": {
                    boxShadow: "none"
                }
            },
            interactive &&
                hover && {
                background: theme.colors.background.tint1
            },
            interactive &&
                active && {
                background: theme.colors.background.tint2
            }
        ] }, interactiveProps, compose_bind_1.safeBind(interactive ? bind : {}, other)),
        react_1.jsx("div", { className: "ListItem__container", css: { display: "flex", alignItems: "center" } },
            contentBefore && (react_1.jsx("div", { className: "ListItem__content-before", css: { marginRight: theme.spaces.md } }, contentBefore)),
            react_1.jsx("div", { className: "ListItem__content", css: { flex: 1, overflow: "hidden" } },
                react_1.jsx(Text_1.Text, { className: "ListItem__primary", wrap: wrap, variant: "body", css: { display: "block", fontWeight: 500 } }, primary),
                secondary && (react_1.jsx(Text_1.Text, { className: "ListItem__secondary", wrap: wrap, css: { display: "block", fontSize: theme.fontSizes[0] }, variant: "body", muted: true }, secondary)),
                children),
            contentAfter && (react_1.jsx("div", { className: "ListItem__content-after", css: { flex: "0 0 auto", marginLeft: theme.spaces.md } }, contentAfter)))));
};
exports.ListItem = ListItem;
exports.ListItem.propTypes = {
    primary: prop_types_1.default.oneOfType([prop_types_1.default.string, prop_types_1.default.node]).isRequired,
    secondary: prop_types_1.default.oneOfType([prop_types_1.default.string, prop_types_1.default.node]),
    contentBefore: prop_types_1.default.node,
    contentAfter: prop_types_1.default.node,
    wrap: prop_types_1.default.bool,
    children: prop_types_1.default.node,
    interactive: prop_types_1.default.bool,
    onPress: prop_types_1.default.func,
    component: prop_types_1.default.elementType
};
const ListSection = (_a) => {
    var { title, children, sticky = true } = _a, other = tslib_1.__rest(_a, ["title", "children", "sticky"]);
    const theme = Providers_1.useTheme();
    const bg = theme.colors.background.layer;
    return (react_1.jsx("div", { css: {
            ":first-child > *": {
                borderTop: "none"
            }
        } },
        react_1.jsx(Menu_1.MenuLabel, Object.assign({ css: {
                position: sticky ? "sticky" : "static",
                top: 0,
                backgroundColor: sticky ? bg : "transparent",
                padding: theme.spaces.sm,
                paddingLeft: theme.spaces.md,
                marginTop: theme.spaces.md,
                [theme.mediaQueries.lg]: {
                    paddingLeft: theme.spaces.lg,
                    paddingRight: theme.spaces.lg
                }
            } }, other), title),
        children));
};
exports.ListSection = ListSection;
exports.ListSection.propTypes = {
    title: prop_types_1.default.string.isRequired,
    sticky: prop_types_1.default.bool,
    children: prop_types_1.default.node
};
