"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MenuLabel = exports.MenuDivider = exports.MenuItem = exports.MenuList = void 0;
const tslib_1 = require("tslib");
/** @jsx jsx */
const react_1 = require("@emotion/react");
const React = tslib_1.__importStar(require("react"));
const Text_1 = require("./Text");
const prop_types_1 = tslib_1.__importDefault(require("prop-types"));
const Sheet_1 = require("./Sheet");
const Providers_1 = require("./Theme/Providers");
const noop_1 = require("./misc/noop");
const touchable_hook_1 = require("touchable-hook");
const classnames_1 = tslib_1.__importDefault(require("classnames"));
const compose_bind_1 = require("./Hooks/compose-bind");
const KeyCodes = {
    ArrowUp: 38,
    ArrowDown: 40,
    Home: 36,
    End: 35
};
const MenuListContext = React.createContext({
    focus: false,
    onKeyDown: () => { }
});
const MenuList = (_a) => {
    var { children, focusableChildren = [] } = _a, other = tslib_1.__rest(_a, ["children", "focusableChildren"]);
    const theme = Providers_1.useTheme();
    const disabled = new Map();
    const [focusIndex, setFocusIndex] = React.useState(null);
    const kids = React.Children.toArray(children);
    const focusComponents = [exports.MenuItem, ...focusableChildren];
    const focusableItems = kids.filter(kid => React.isValidElement(kid) &&
        focusComponents.indexOf(kid.type) > -1);
    const lastIndex = focusableItems.length - 1;
    const firstIndex = 0;
    return (react_1.jsx("div", Object.assign({ role: "menu", onKeyDown: (e) => {
            if (e.keyCode === KeyCodes.ArrowDown ||
                (e.keyCode === KeyCodes.ArrowUp && focusIndex === null)) {
                e.preventDefault();
                setFocusIndex(0);
            }
        }, css: {
            minWidth: "200px",
            display: "block",
            padding: `${theme.spaces.sm} 0`
        } }, other), kids.map(kid => {
        if (!React.isValidElement(kid)) {
            return null;
        }
        const i = focusableItems.indexOf(kid);
        if (i < 0) {
            return kid;
        }
        disabled.set(i, kid.props.disabled);
        function focusDown(current) {
            const next = current + 1 > lastIndex ? firstIndex : current + 1;
            if (disabled.get(next)) {
                focusDown(next);
            }
            else {
                setFocusIndex(next);
            }
        }
        function focusUp(current) {
            const next = current - 1 < firstIndex ? lastIndex : current - 1;
            if (disabled.get(next)) {
                focusUp(next);
            }
            else {
                setFocusIndex(next);
            }
        }
        const index = focusIndex || 0;
        return (react_1.jsx(MenuListContext.Provider, { key: i, value: {
                focus: i === focusIndex,
                onKeyDown: (e) => {
                    if (e.keyCode === KeyCodes.ArrowDown) {
                        e.preventDefault();
                        focusDown(index);
                    }
                    else if (e.keyCode === KeyCodes.ArrowUp) {
                        e.preventDefault();
                        focusUp(index);
                    }
                    else if (e.keyCode === KeyCodes.Home) {
                        e.preventDefault();
                        setFocusIndex(firstIndex);
                    }
                    else if (e.keyCode === KeyCodes.End) {
                        e.preventDefault();
                        setFocusIndex(lastIndex);
                    }
                }
            } }, kid));
    })));
};
exports.MenuList = MenuList;
exports.MenuList.propTypes = {
    children: prop_types_1.default.node,
    focusableChildren: prop_types_1.default.arrayOf(prop_types_1.default.elementType)
};
//类似Button处理。 Can't perform a React state update on an unmounted；手机onPress onClick。估计useTouchable有毛病。
const MenuItem = (_a) => {
    var { contentBefore, contentAfter, onPress = noop_1.noOp, className = "", component: Component = "div", role = "menuitem", noBind = true, children, disabled, onClick } = _a, other = tslib_1.__rest(_a, ["contentBefore", "contentAfter", "onPress", "className", "component", "role", "noBind", "children", "disabled", "onClick"]);
    const theme = Providers_1.useTheme();
    const dark = theme.colors.mode === "dark";
    const localRef = React.useRef(null);
    const closeParent = React.useContext(Sheet_1.RequestCloseContext);
    const { focus, onKeyDown } = React.useContext(MenuListContext);
    const isLink = Component === "a" || other.href || other.to;
    //touchable-hook底下,触发onScroll（）可能报错 unmount; dispatch<> <- focus-trap()。
    const { bind, hover, active } = touchable_hook_1.useTouchable({
        onPress: select,
        terminateOnScroll: false,
        disabled,
        delay: 0,
        behavior: isLink ? "link" : "button"
    });
    React.useEffect(() => {
        if (focus && localRef.current) {
            localRef.current.focus();
        }
    }, [focus, localRef]);
    //必须，onPress+ 原生onClick；
    function select() {
        onPress();
        closeParent();
    }
    return (react_1.jsx(Component, Object.assign({ className: classnames_1.default("MenuItem", "Touchable", className, {
            "Touchable--hover": hover,
            "Touchable--active": active
        }), css: [
            {
                cursor: "pointer",
                opacity: disabled ? 0.3 : 1,
                display: "flex",
                textDecoration: "none",
                transition: "background-color 0.1s ease",
                WebkitTapHighlightColor: "transparent",
                color: theme.colors.text.default,
                alignItems: "center",
                ":focus": {
                    outline: theme.outline
                },
                ":focus:not([data-focus-visible-added])": {
                    outline: "none"
                },
                padding: `${theme.spaces.sm} ${theme.spaces.md}`,
                [theme.mediaQueries.sm]: {
                    padding: `${theme.spaces.none} ${theme.spaces.none}`
                },
                [theme.mediaQueries.md]: {
                    padding: `calc(${theme.spaces.sm} + 0.25rem) calc(${theme.spaces.md} + 0.25rem)`,
                },
                [theme.mediaQueries.lg]: {
                    padding: `${theme.spaces.xs} ${theme.spaces.md}`
                },
                [theme.mediaQueries.xl]: {
                    padding: `${theme.spaces.sm} ${theme.spaces.lg}`
                }
            },
            hover && {
                background: dark
                    ? theme.colors.background.tint2
                    : theme.colors.background.tint1
            },
            active && {
                background: theme.colors.background.tint2
            }
        ], role: role, tabIndex: disabled ? -1 : 0, "data-trigger-close": true }, compose_bind_1.safeBind(bind, {
        ref: localRef,
        onKeyDown: (e) => {
            e.stopPropagation();
            if (onKeyDown)
                onKeyDown(e);
        },
        onClick: (e) => {
            e.stopPropagation();
        }
    }, other)),
        contentBefore,
        typeof children === "string" ? (react_1.jsx(Text_1.Text, { wrap: false, css: {
                paddingLeft: contentBefore ? theme.spaces.md : 0,
                paddingRight: contentAfter ? theme.spaces.md : 0,
                flex: 1,
                color: "inherit"
            } }, children)) : (children),
        typeof contentAfter === "string" ? (react_1.jsx(Text_1.Text, { muted: true }, contentAfter)) : (contentAfter)));
};
exports.MenuItem = MenuItem;
exports.MenuItem.propTypes = {
    onSelect: prop_types_1.default.func,
    component: prop_types_1.default.string,
    disabled: prop_types_1.default.bool,
    children: prop_types_1.default.node,
    contentBefore: prop_types_1.default.node,
    contentAfter: prop_types_1.default.node,
    onPress: prop_types_1.default.func,
    className: prop_types_1.default.string,
    role: prop_types_1.default.string
};
function MenuDivider(props) {
    const theme = Providers_1.useTheme();
    return (react_1.jsx("div", Object.assign({ css: {
            height: 0,
            margin: `${theme.spaces.sm} 0`,
            overflow: "hidden",
            borderTop: "1px solid",
            borderColor: theme.colors.border.muted
        } }, props)));
}
exports.MenuDivider = MenuDivider;
const MenuLabel = props => {
    const theme = Providers_1.useTheme();
    return (react_1.jsx(Text_1.Text, Object.assign({ variant: "uppercase", css: {
            padding: `${theme.spaces.xs} ${theme.spaces.md}`
        } }, props)));
};
exports.MenuLabel = MenuLabel;
exports.MenuLabel.propTypes = {
    children: prop_types_1.default.node
};
