"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ScrollView = void 0;
const tslib_1 = require("tslib");
/** @jsx jsx */
const react_1 = require("@emotion/react");
const React = tslib_1.__importStar(require("react"));
const react_gesture_responder_1 = require("react-gesture-responder");
const react_spring_1 = require("react-spring");
const prop_types_1 = tslib_1.__importDefault(require("prop-types"));
const compose_bind_1 = require("./Hooks/compose-bind");
/**
 * A scroll view with some helpers, including:
 *  - smooth scrolling
 *  - gesture claiming
 * @param param0
 * @param componentRef  改成 ref
 */
//export const ScrollView= React.forwardRef(ScrollViewForward);   // 报警！嵌套RefForwardingComponent 的forwardRef;
exports.ScrollView = React.forwardRef((_a, ref) => {
    var { overflowY, children, overflowX, innerRef, scrollAnimationConfig = { tension: 190, friction: 15, mass: 0.2 } } = _a, other = tslib_1.__rest(_a, ["overflowY", "children", "overflowX", "innerRef", "scrollAnimationConfig"]);
    const scrRef = React.useRef(null);
    /**
     * A spring for animating scroll positions
     */
    const [, setScroll] = react_spring_1.useSpring(() => {
        return {
            config: scrollAnimationConfig,
            from: { x: 0, y: 0 },
            to: { x: 0, y: 0 },
            onFrame: (animated) => {
                if (overflowX && scrRef.current) {
                    scrRef.current.scrollLeft = animated.x;
                }
                if (overflowY && scrRef.current) {
                    scrRef.current.scrollTop = animated.y;
                }
            }
        };
    });
    /**
     * Expose an imperate scrollTo method
     */
    React.useImperativeHandle(ref, () => ({
        scrollTo: (x, y) => {
            if (scrRef.current) {
                const from = {
                    x: scrRef.current.scrollLeft,
                    y: scrRef.current.scrollTop
                };
                setScroll({
                    from,
                    to: { x, y },
                    reset: true
                });
            }
        }
    }), [setScroll]);
    /**
     * Use a pan responder to determine if our scrollview should
     * claim the responder (and cancel other gestures out). Only
     * enabled on touch devices.
     */
    const { bind } = react_gesture_responder_1.useGestureResponder({
        onStartShouldSet: () => false,
        onTerminationRequest: () => false,
        onMoveShouldSet: ({ initial, initialDirection, xy }) => {
            if (initialDirection[0] !== 0 && overflowX) {
                return true;
            }
            if (initialDirection[1] !== 0 && overflowY) {
                return true;
            }
            return false;
        }
    }, {
        enableMouse: false
    });
    // 不可把innerRef?  与 ref?  都绑定到内部第二个div，scrRef上。
    return (react_1.jsx("div", Object.assign({ className: "ScrollView" }, other, bind),
        react_1.jsx("div", Object.assign({ className: "ScrollView__scroll-containerr", css: {
                transform: "translateZ(0)",
                overflowX: overflowX ? "scroll" : undefined,
                overflowY: overflowY ? "scroll" : undefined,
                WebkitOverflowScrolling: "touch"
            } }, compose_bind_1.safeBind({ ref: innerRef }, { ref: scrRef }, other)), children)));
});
exports.ScrollView.propTypes = {
    overflowY: prop_types_1.default.bool,
    children: prop_types_1.default.node,
    overflowX: prop_types_1.default.bool,
    scrollAnimationConfig: prop_types_1.default.shape({
        tension: prop_types_1.default.number,
        mass: prop_types_1.default.number,
        friction: prop_types_1.default.number
    })
};
