"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Spinner = void 0;
const tslib_1 = require("tslib");
/** @jsx jsx */
const react_1 = require("@emotion/react");
const React = tslib_1.__importStar(require("react"));
const visually_hidden_1 = tslib_1.__importDefault(require("@reach/visually-hidden"));
const prop_types_1 = tslib_1.__importDefault(require("prop-types"));
const Text_1 = require("./Text");
const Providers_1 = require("./Theme/Providers");
const spin = react_1.keyframes `
  to { 
    transform: rotate(360deg); 
  }
`;
const sizeStyles = {
    xs: react_1.css({ width: "0.5rem", height: "0.5rem" }),
    sm: react_1.css({ width: "0.75rem", height: "0.75rem" }),
    md: react_1.css({ width: "1rem", height: "1rem" }),
    lg: react_1.css({ width: "1.25rem", height: "1.25rem" }),
    xl: react_1.css({ width: "1.5rem", height: "1.5rem" })
};
// spinner css based on one provided by bootstrap
// https://getbootstrap.com/docs/4.3/components/spinners/
const Spinner = (_a) => {
    var { delay = 400, size = "md", center, label } = _a, other = tslib_1.__rest(_a, ["delay", "size", "center", "label"]);
    const theme = Providers_1.useTheme();
    const [show, setShow] = React.useState(delay === 0 ? true : false);
    React.useEffect(() => {
        const timer = setTimeout(() => {
            setShow(true);
        }, delay);
        return () => {
            clearTimeout(timer);
        };
    }, [delay]);
    return (react_1.jsx("div", Object.assign({ className: "Spinner", css: [
            {
                opacity: show ? 1 : 0,
                display: "inline-block",
                transition: "opacity 0.4s cubic-bezier(0.35,0,0.25,1)"
            },
            center && {
                width: "100%",
                height: "100%",
                boxSizing: "border-box",
                display: "flex",
                alignItems: "center",
                alignSelf: "center",
                justifyContent: "center"
            }
        ] }, other),
        react_1.jsx("div", { className: "Spinner__container", role: "status", css: {
                color: theme.colors.text.default,
                textAlign: "center",
                display: "inline-block"
            } },
            react_1.jsx("div", { className: "Spinner__spinner", css: [
                    react_1.css `
              display: inline-block;
              vertical-align: text-bottom;
              border: 0.15em solid currentColor;
              border-right-color: transparent;
              border-radius: 50%;
              animation: ${spin} 0.75s linear infinite;
            `,
                    sizeStyles[size]
                ] }),
            label ? (react_1.jsx(Text_1.Text, { className: "Spinner__label", wrap: false, css: { display: "block", marginTop: theme.spaces.sm }, variant: "subtitle" }, label)) : (react_1.jsx(visually_hidden_1.default, null, "Loading")))));
};
exports.Spinner = Spinner;
exports.Spinner.propTypes = {
    delay: prop_types_1.default.number,
    center: prop_types_1.default.bool,
    label: prop_types_1.default.string,
    size: prop_types_1.default.oneOf(["xs", "sm", "md", "lg", "xl"])
};
