"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ExpandingRow = exports.TableBody = exports.TableCell = exports.TableRow = exports.TableHead = exports.Table = void 0;
const tslib_1 = require("tslib");
/** @jsx jsx */
const react_1 = require("@emotion/react");
const React = tslib_1.__importStar(require("react"));
const Layer_1 = require("./Layer");
const prop_types_1 = tslib_1.__importDefault(require("prop-types"));
const Providers_1 = require("./Theme/Providers");
const TableSectionContext = React.createContext({
    type: "TableHead"
});
const TableContext = React.createContext({ fixed: false });
const Table = (_a) => {
    var { children, minWidth, fixed } = _a, other = tslib_1.__rest(_a, ["children", "minWidth", "fixed"]);
    const theme = Providers_1.useTheme();
    return (react_1.jsx("div", { css: {
            width: "100%",
            display: "block",
            overflowX: minWidth ? "auto" : "initial"
        } },
        react_1.jsx("table", Object.assign({ css: {
                borderSpacing: 0,
                borderCollapse: "separate",
                width: "100%",
                fontFamily: theme.fonts.base,
                WebkitAppearance: "none",
                WebkitFontSmoothing: "antialiased",
                display: "table",
                minWidth,
                tableLayout: fixed ? "fixed" : undefined
            } }, other),
            fixed && (react_1.jsx("colgroup", null, fixed.map((width, i) => {
                return react_1.jsx("col", { key: i, width: width });
            }))),
            react_1.jsx(TableContext.Provider, { value: { fixed: fixed ? true : false } }, children))));
};
exports.Table = Table;
exports.Table.propTypes = {
    minWidth: prop_types_1.default.string,
    fixed: prop_types_1.default.arrayOf(prop_types_1.default.string),
    children: prop_types_1.default.node
};
function TableHead(_a) {
    var { children } = _a, other = tslib_1.__rest(_a, ["children"]);
    return (react_1.jsx("thead", Object.assign({ css: {
            display: "table-header-group"
        } }, other),
        react_1.jsx(TableSectionContext.Provider, { value: { type: "TableHead" } }, children)));
}
exports.TableHead = TableHead;
const TableRow = (_a) => {
    var { onClick, children } = _a, other = tslib_1.__rest(_a, ["onClick", "children"]);
    const theme = Providers_1.useTheme();
    const { type: tableSectionType } = React.useContext(TableSectionContext);
    const buttonProps = onClick
        ? {
            role: "button",
            tabIndex: 0
        }
        : {};
    return (react_1.jsx("tr", Object.assign({ onClick: onClick, css: {
            height: tableSectionType === "TableHead" ? "31px" : "49px",
            display: "table-row",
            outline: "none",
            verticalAlign: "middle",
            cursor: onClick ? "pointer" : "default",
            ":hover": {
                background: onClick ? theme.colors.background.tint1 : "none"
            }
        } }, buttonProps, other), children));
};
exports.TableRow = TableRow;
exports.TableRow.propTypes = {
    onClick: prop_types_1.default.func,
    children: prop_types_1.default.node
};
/**
 * TableCell, used for both <td> and <th> elements.
 */
const tableCellAlignments = {
    right: react_1.css({
        textAlign: "right",
        flexDirection: "row-reverse"
    }),
    left: react_1.css({
        textAlign: "left"
    }),
    center: react_1.css({
        textAlign: "center"
    }),
    justify: react_1.css({
        textAlign: "justify"
    })
};
const TableCell = (_a) => {
    var { align = "left", variant, component, ellipsis, children } = _a, other = tslib_1.__rest(_a, ["align", "variant", "component", "ellipsis", "children"]);
    const theme = Providers_1.useTheme();
    const { type: tableSectionType } = React.useContext(TableSectionContext);
    const Component = component || (tableSectionType === "TableHead" ? "th" : "td");
    const type = variant || (tableSectionType === "TableHead" ? "head" : "body");
    return (react_1.jsx(Component, Object.assign({ css: [
            {
                zIndex: 4,
                position: "relative",
                borderBottom: "1px solid",
                borderColor: tableSectionType === "TableBody"
                    ? theme.colors.border.muted
                    : theme.colors.border.default,
                display: "table-cell",
                padding: `${theme.spaces.xs} ${theme.spaces.sm}`,
                [theme.mediaQueries.lg]: {
                    paddingLeft: theme.spaces.md,
                    paddingRight: theme.spaces.md
                },
                ":last-child": {
                    paddingRight: theme.spaces.md
                }
            },
            ellipsis && {
                whiteSpace: "nowrap",
                textOverflow: "ellipsis",
                overflow: "hidden"
            },
            type === "head"
                ? {
                    fontWeight: 500,
                    fontSize: theme.fontSizes[0],
                    color: theme.colors.text.muted
                }
                : {
                    fontWeight: 400,
                    fontSize: theme.fontSizes[0],
                    color: theme.colors.text.default
                },
            tableCellAlignments[align]
        ], scope: "col" }, other), children));
};
exports.TableCell = TableCell;
exports.TableCell.propTypes = {
    align: prop_types_1.default.oneOf(Object.keys(tableCellAlignments)),
    variant: prop_types_1.default.oneOf(["body", "head"]),
    component: prop_types_1.default.elementType,
    ellipsis: prop_types_1.default.bool,
    children: prop_types_1.default.node
};
function TableBody(_a) {
    var { children } = _a, other = tslib_1.__rest(_a, ["children"]);
    return (react_1.jsx("tbody", Object.assign({ css: {
            display: "table-row-group"
        } }, other),
        react_1.jsx(TableSectionContext.Provider, { value: { type: "TableBody" } }, children)));
}
exports.TableBody = TableBody;
const ExpandingRow = ({ content, children }) => {
    const theme = Providers_1.useTheme();
    const [selected, setSelected] = React.useState(false);
    function close() {
        setSelected(false);
    }
    function open() {
        setSelected(true);
    }
    return (react_1.jsx(TableBody, null,
        react_1.jsx(exports.TableRow, { onClick: open }, children),
        selected && (react_1.jsx("tr", { css: { display: "table-row", height: "100px" } },
            react_1.jsx("td", { colSpan: React.Children.count(children), css: {
                    borderBottom: 0,
                    width: "inherit",
                    padding: 0,
                    position: "relative"
                } },
                react_1.jsx("div", { css: {
                        zIndex: 3,
                        width: "inherit",
                        position: "relative",
                        paddingBottom: "24px"
                    } },
                    react_1.jsx("div", { css: {
                            position: "relative",
                            whiteSpace: "normal",
                            height: "auto",
                            display: "block",
                            paddingTop: "24px"
                        } }, typeof content === "function" ? content(close) : content)),
                react_1.jsx(Layer_1.Layer, { css: {
                        position: "absolute",
                        top: "-49px",
                        left: "-16px",
                        right: "-16px",
                        borderRadius: theme.radii.md,
                        bottom: 0,
                        zIndex: 2
                    } }, null))))));
};
exports.ExpandingRow = ExpandingRow;
exports.ExpandingRow.propTypes = {
    content: prop_types_1.default.oneOfType([prop_types_1.default.func, prop_types_1.default.node]),
    children: prop_types_1.default.node
};
