"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Text = exports.getVariantStyles = void 0;
const tslib_1 = require("tslib");
/** @jsx jsx */
const react_1 = require("@emotion/react");
const React = tslib_1.__importStar(require("react"));
const prop_types_1 = tslib_1.__importDefault(require("prop-types"));
const Providers_1 = require("./Theme/Providers");
const getVariantStyles = (theme, variant) => {
    switch (variant) {
        case "uppercase":
            return react_1.css({
                textTransform: "uppercase",
                fontSize: theme.fontSizes[0],
                fontWeight: 600,
                color: theme.colors.text.muted,
                letterSpacing: "-0.02em"
            });
        case "body":
            return react_1.css({
                fontSize: theme.fontSizes[1]
            });
        case "paragraph":
            return react_1.css({
                fontSize: theme.fontSizes[1],
                marginBottom: theme.spaces.md
            });
        case "subtitle":
            return react_1.css({
                fontSize: theme.fontSizes[0],
                fontWeight: 400,
                color: theme.colors.text.muted,
                lineHeight: theme.lineHeights.body
            });
        case "lead":
            return react_1.css({
                fontWeight: 400,
                fontSize: theme.fontSizes[2]
            });
        case "h6":
            return react_1.css({
                color: theme.colors.text.heading,
                fontWeight: theme.fontWeights.heading,
                lineHeight: 1.5,
                fontSize: theme.fontSizes[1],
                marginBottom: theme.spaces.sm
            });
        case "h5":
            return react_1.css({
                color: theme.colors.text.heading,
                fontWeight: theme.fontWeights.heading,
                fontSize: theme.fontSizes[2],
                lineHeight: theme.lineHeights.heading,
                marginBottom: theme.spaces.sm
            });
        case "h4":
            return react_1.css({
                color: theme.colors.text.heading,
                fontWeight: theme.fontWeights.heading,
                fontSize: theme.fontSizes[3],
                lineHeight: theme.lineHeights.heading,
                marginBottom: theme.spaces.sm,
                letterSpacing: "-0.2px"
            });
        case "h3":
            return react_1.css({
                color: theme.colors.text.heading,
                fontWeight: theme.fontWeights.heading,
                fontSize: theme.fontSizes[4],
                lineHeight: theme.lineHeights.heading,
                marginBottom: theme.spaces.sm
            });
        case "h2":
            return react_1.css({
                color: theme.colors.text.heading,
                fontWeight: theme.fontWeights.heading,
                fontSize: theme.fontSizes[5],
                lineHeight: theme.lineHeights.heading,
                marginBottom: theme.spaces.sm,
                letterSpacing: "-0.2px"
            });
        case "h1":
            return react_1.css({
                color: theme.colors.text.heading,
                fontWeight: theme.fontWeights.heading,
                fontSize: theme.fontSizes[6],
                lineHeight: theme.lineHeights.heading,
                marginBottom: theme.spaces.sm,
                letterSpacing: "-0.2px"
            });
        case "display3":
            return react_1.css({
                color: theme.colors.text.heading,
                fontWeight: theme.fontWeights.display,
                fontSize: theme.fontSizes[5],
                lineHeight: theme.lineHeights.heading,
                marginBottom: theme.spaces.sm,
                [theme.mediaQueries.lg]: {
                    fontSize: theme.fontSizes[6]
                }
            });
        case "display2":
            return react_1.css({
                color: theme.colors.text.heading,
                fontWeight: theme.fontWeights.display,
                fontSize: theme.fontSizes[6],
                lineHeight: theme.lineHeights.heading,
                marginBottom: theme.spaces.sm,
                [theme.mediaQueries.lg]: {
                    fontSize: theme.fontSizes[7]
                }
            });
        case "display1":
            return react_1.css({
                color: theme.colors.text.heading,
                fontWeight: theme.fontWeights.display,
                fontSize: theme.fontSizes[7],
                lineHeight: theme.lineHeights.heading,
                marginBottom: theme.spaces.sm,
                [theme.mediaQueries.lg]: {
                    fontSize: theme.fontSizes[8]
                }
            });
    }
};
exports.getVariantStyles = getVariantStyles;
const element = {
    display1: "h1",
    display2: "h1",
    display3: "h1",
    h1: "h1",
    h2: "h2",
    h3: "h3",
    h4: "h4",
    h5: "h5",
    h6: "h6",
    uppercase: "div",
    subtitle: "div",
    body: "span",
    paragraph: "p",
    hidden: "span",
    lead: "p"
};
const basicStyles = (theme) => ({
    base: react_1.css({
        boxSizing: "border-box",
        margin: 0,
        fontWeight: theme.fontWeights.body,
        lineHeight: theme.lineHeights.body,
        fontFamily: theme.fonts.base,
        fontSize: theme.fontSizes[1],
        color: theme.colors.text.default,
        WebkitFontSmoothing: "antialiased",
        WebkitTextSizeAdjust: "none"
    }),
    noGutter: react_1.css({
        marginBottom: 0
    }),
    noWrap: react_1.css({
        overflow: "hidden",
        textOverflow: "ellipsis",
        whiteSpace: "nowrap"
    }),
    muted: react_1.css({
        color: theme.colors.text.muted
    })
});
const Text = (_a) => {
    var { variant = "body", wrap = true, gutter = true, muted, component } = _a, other = tslib_1.__rest(_a, ["variant", "wrap", "gutter", "muted", "component"]);
    const Component = component || element[variant];
    const theme = Providers_1.useTheme();
    const variantStyles = React.useMemo(() => exports.getVariantStyles(theme, variant), [
        theme,
        variant
    ]);
    const styles = React.useMemo(() => basicStyles(theme), [theme]);
    return (react_1.jsx(Component, Object.assign({ css: [
            styles.base,
            !wrap && styles.noWrap,
            muted && styles.muted,
            variantStyles,
            !gutter && styles.noGutter
        ] }, other)));
};
exports.Text = Text;
exports.Text.propTypes = {
    variant: prop_types_1.default.oneOf([
        "uppercase",
        "hidden",
        "body",
        "paragraph",
        "subtitle",
        "lead",
        "h6",
        "h5",
        "h4",
        "h3",
        "h2",
        "h1",
        "display3",
        "display2",
        "display1"
    ]),
    wrap: prop_types_1.default.bool,
    muted: prop_types_1.default.bool,
    gutter: prop_types_1.default.bool,
    component: prop_types_1.default.elementType
};
