"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useToast = void 0;
const tslib_1 = require("tslib");
/** @jsx jsx */
const react_1 = require("@emotion/react");
const React = tslib_1.__importStar(require("react"));
const toasted_notes_1 = tslib_1.__importDefault(require("toasted-notes"));
const Alert_1 = require("./Alert");
const Providers_1 = require("./Theme/Providers");
const toastStyles = react_1.css `
  .Toaster__message-wrapper {
    padding: 8px;
    text-align: left;
  }
`;
/**
 * We export toast as a hook because it allows us to consume
 * the current theme context that it's in and pass that
 * onto our render function
 */
function useToast() {
    const theme = Providers_1.useTheme();
    function notify({ position, duration, render, title, subtitle, intent }) {
        const options = {
            position,
            duration
        };
        if (render) {
            return toasted_notes_1.default.notify(({ onClose, id }) => (react_1.jsx(React.Fragment, null,
                react_1.jsx(react_1.Global, { styles: toastStyles }),
                react_1.jsx(Providers_1.ThemeProvider, { theme: theme }, render({ onClose, id })))), options);
        }
        toasted_notes_1.default.notify(({ onClose, id }) => (react_1.jsx(React.Fragment, null,
            react_1.jsx(react_1.Global, { styles: toastStyles }),
            react_1.jsx(Providers_1.ThemeProvider, { theme: theme },
                react_1.jsx(Alert_1.Alert, { id: String(id), title: title, component: "div", elevation: "md", subtitle: subtitle, intent: intent, onRequestClose: onClose })))), options);
    }
    return notify;
}
exports.useToast = useToast;
