"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Tooltip = exports.arrowStyles = void 0;
const tslib_1 = require("tslib");
/** @jsx jsx */
const react_1 = require("@emotion/react");
const React = tslib_1.__importStar(require("react"));
const Positions_1 = require("./Positions");
const Text_1 = require("./Text");
const react_spring_1 = require("react-spring");
const prop_types_1 = tslib_1.__importDefault(require("prop-types"));
const is_mobile_1 = require("is-mobile");
const use_uid_1 = require("./Hooks/use-uid");
const Providers_1 = require("./Theme/Providers");
const arrowStyles = (color) => react_1.css(`
  position: absolute;
  width: 3em;
  height: 3em;
  &[data-placement*='bottom'] {
    bottom: 100%;
    left: 0;
    margin-top: 0em;
    width: 1em;
    height: 0.25em;
    &::before {
      width: 10px;
      border: none;
      height: 10px;
      background: ${color};
      border-top: 1px solid ${color === "white" ? " #dee2e685" : color};
      border-right: 1px solid ${color === "white" ? "#dee2e685" : color};
      transform: rotate(-45deg);
      border-radius: 2px;
      margin-top: -1px;
    }
  }
  &[data-placement*='top'] {
    top: 100%;
    left: 0;
    margin-bottom: 0;
    width: 1em;
    height: 0.25em;
    &::before {
      border-width: 0.25em 0.25em 0 0.25em;
      border-color: ${color} transparent transparent transparent;
    }
  }
  &[data-placement*='right'] {
    right: 100%;
    height: 1em;
    width: 0.25em;
    &::before {
      border-width: 0.25em 0.25em 0.25em 0;
      border-color: transparent ${color} transparent transparent;
    }
  }
  &[data-placement*='left'] {
    left: 100%;
    height: 1em;
    width: 0.25em;
    &::before {
      border-width: 0.25em 0 0.25em 0.25em;
      border-color: transparent transparent transparent ${color};
    }
  }
  &::before {
    content: '';
    margin: auto;
    display: block;
    width: 0;
    height: 0;
    border-style: solid;
  }
`);
exports.arrowStyles = arrowStyles;
const Tooltip = (_a) => {
    var { placement, children, content, delayIn = 0, delayOut = 0, hover: enableHover = true, maxWidth = "300px" } = _a, other = tslib_1.__rest(_a, ["placement", "children", "content", "delayIn", "delayOut", "hover", "maxWidth"]);
    const id = use_uid_1.useUid();
    const theme = Providers_1.useTheme();
    const dark = theme.colors.mode === "dark";
    const [show, setShow] = React.useState(false);
    const [hovering, setHovering] = React.useState(false);
    const [delayShow, setDelayShow] = React.useState(false);
    function renderTrigger({ ref }) {
        // We don't want tooltips to show on touch based devices
        // so we just return the child without the event handlers.
        // Really not sure if this is the best way to do this.
        if (is_mobile_1.isMobile()) {
            return children;
        }
        const child = React.Children.only(children);
        // Enable on non-mobile devices
        return React.cloneElement(child, {
            ref,
            "aria-describedby": id,
            onMouseEnter: () => {
                if (!show)
                    setShow(true);
            },
            onMouseLeave: () => {
                if (show)
                    setShow(false);
            },
            onFocus: () => {
                if (!show)
                    setShow(true);
            },
            onBlur: () => {
                if (show)
                    setShow(false);
            }
        });
    }
    function onMouseLeave() {
        setHovering(false);
    }
    function onMouseEnter() {
        setHovering(true);
    }
    React.useEffect(() => {
        let timeoutIn;
        let timeoutOut;
        if (show) {
            timeoutIn = setTimeout(() => {
                setDelayShow(true);
            }, delayIn);
        }
        else {
            timeoutOut = setTimeout(() => {
                setDelayShow(false);
            }, delayOut);
        }
        return () => {
            if (timeoutIn) {
                clearInterval(timeoutIn);
            }
            if (timeoutOut) {
                clearInterval(timeoutOut);
            }
        };
    }, [delayIn, delayOut, show]);
    return (react_1.jsx(Positions_1.Positioner, { placement: placement, isOpen: delayShow || (hovering && enableHover), target: renderTrigger }, ({ placement, ref, style, arrowProps }, state) => (react_1.jsx(react_spring_1.animated.div, Object.assign({ id: id, "data-placement": placement, role: "tooltip", className: "Tooltip", ref: ref, style: Object.assign(Object.assign({}, style), { opacity: state.opacity }), css: {
            zIndex: theme.zIndices.tooltip,
            margin: theme.spaces.xs
        }, onMouseEnter: onMouseEnter, onMouseLeave: onMouseLeave }, other),
        react_1.jsx("div", { className: "Tooltip__content", "data-placement": placement, css: exports.arrowStyles(dark
                ? theme.colors.background.tint1
                : theme.colors.palette.gray.dark), ref: arrowProps.ref, style: arrowProps.style }),
        react_1.jsx(Text_1.Text, { className: "Tooltip__text", variant: "body", css: [
                {
                    fontSize: theme.fontSizes[0],
                    display: "inline-block",
                    margin: 0,
                    textAlign: "center",
                    maxWidth,
                    boxShadow: theme.shadows.md,
                    borderRadius: theme.radii.sm,
                    padding: `${theme.spaces.xs} ${theme.spaces.md}`,
                    color: "white",
                    background: dark
                        ? theme.colors.background.tint1
                        : theme.colors.palette.gray.dark
                }
            ] }, content)))));
};
exports.Tooltip = Tooltip;
exports.Tooltip.propTypes = {
    content: prop_types_1.default.node.isRequired,
    children: prop_types_1.default.node.isRequired,
    hover: prop_types_1.default.bool,
    delayIn: prop_types_1.default.number,
    delayOut: prop_types_1.default.number,
    placement: prop_types_1.default.oneOf([
        "auto-start",
        "auto",
        "auto-end",
        "top-start",
        "top",
        "top-end",
        "right-start",
        "right",
        "right-end",
        "bottom-end",
        "bottom",
        "bottom-start",
        "left-end",
        "left",
        "left-start"
    ])
};
