"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ThemeExamples = void 0;
const tslib_1 = require("tslib");
/** @jsx jsx */
const react_1 = require("@emotion/react");
const React = tslib_1.__importStar(require("react"));
const react_2 = require("@storybook/react");
const use_infinite_scroll_1 = require("../Hooks/use-infinite-scroll");
const faker = tslib_1.__importStar(require("faker"));
const ScrollView_1 = require("../ScrollView");
const List_1 = require("../List");
const Skeleton_1 = require("../Skeleton");
const Avatar_1 = require("../Avatar");
const Layer_1 = require("../Layer");
const Icons_1 = require("../Icons");
const Providers_1 = require("../Theme/Providers");
function fetchdata() {
    return new Promise(resolve => {
        setTimeout(() => {
            resolve(void 0);
        }, 800);
    });
}
function getUser() {
    faker.seed(0);
    return {
        name: faker.name.firstName() + " " + faker.name.lastName(),
        uid: faker.random.uuid(),
        description: faker.lorem.sentence()
    };
}
function Example() {
    const theme = Providers_1.useTheme();
    const ref = React.useRef(null);
    const [items, setItems] = React.useState(Array.from(new Array(10)).map(() => getUser()));
    const [page, setPage] = React.useState(0);
    const [fetching] = use_infinite_scroll_1.useInfiniteScroll({
        container: ref,
        hasMore: page < 4,
        onFetch: () => {
            return fetchdata().then(() => {
                setItems([...items, ...Array.from(new Array(10)).map(() => getUser())]);
                setPage(page + 1);
            });
        }
    });
    return (react_1.jsx(Layer_1.Layer, { css: {
            width: "400px",
            overflow: "hidden"
        } },
        react_1.jsx(ScrollView_1.ScrollView, { css: {
                height: "280px"
            }, overflowY: true, innerRef: ref },
            react_1.jsx(List_1.List, null,
                items.map(item => (react_1.jsx(List_1.ListItem, { key: item.uid, contentBefore: react_1.jsx(Avatar_1.Avatar, { name: item.name }), primary: item.name, secondary: item.description, contentAfter: react_1.jsx(Icons_1.IconChevronRight, { color: theme.colors.text.muted }) }))),
                fetching && (react_1.jsx(List_1.ListItem, { interactive: false, "aria-live": "polite", "aria-busy": "true", primary: react_1.jsx(Skeleton_1.Skeleton, { animated: true, css: { width: "100px" } }), secondary: react_1.jsx(Skeleton_1.Skeleton, { animated: true }), contentBefore: react_1.jsx(Skeleton_1.Skeleton, { animated: true, css: {
                            width: "3.27rem",
                            height: "3.27rem",
                            borderRadius: "50%"
                        } }) }))))));
}
function WindowExample() {
    const [items, setItems] = React.useState(Array.from(new Array(10)).map(() => faker.name.firstName()));
    const [page, setPage] = React.useState(0);
    const [fetching] = use_infinite_scroll_1.useInfiniteScroll({
        hasMore: page < 4,
        onFetch: () => {
            return fetchdata().then(() => {
                setItems([
                    ...items,
                    ...Array.from(new Array(10)).map(() => faker.name.firstName())
                ]);
                setPage(page + 1);
            });
        }
    });
    return (react_1.jsx("div", null,
        items.map(item => (react_1.jsx("div", { css: { height: "40px", border: "1px solid" }, key: item }, item))),
        fetching && react_1.jsx("div", null, "Loading...")));
}
exports.ThemeExamples = react_2.storiesOf("InfiniteScroll", module)
    .add("Basic usage", () => (react_1.jsx("div", { css: { padding: "1rem" } },
    react_1.jsx(Example, null))))
    .add("Window scroll", () => react_1.jsx(WindowExample, null));
