"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ThemeExamples = void 0;
const tslib_1 = require("tslib");
/** @jsx jsx */
const react_1 = require("@emotion/react");
const react_2 = require("@storybook/react");
const Providers_1 = require("../Theme/Providers");
const Theme_1 = tslib_1.__importDefault(require("../Theme"));
const Layer_1 = require("../Layer");
const Popover_1 = require("../Popover");
const Menu_1 = require("../Menu");
const Button_1 = require("../Button");
const Text_1 = require("../Text");
const palx_1 = tslib_1.__importDefault(require("palx"));
const Link_1 = require("../Link");
const React = tslib_1.__importStar(require("react"));
const colors_1 = require("../Theme/colors");
const Tooltip_1 = require("../Tooltip");
const IconButton_1 = require("../IconButton");
const Icons_1 = require("../Icons");
const customPalette = palx_1.default("#007bff");
const colors = colors_1.generateColorsFromScales(customPalette, {
// generateIntents
});
// function generateIntents(palette: PaletteType) {
//   return {
//     none: palette.gray,
//     primary: palette.teal,
//     success: palette.violet,
//     danger: palette.red,
//     warning: palette.yellow
//   };
// }
const custom = Object.assign(Object.assign(Object.assign({}, Theme_1.default), colors), { fonts: {
        base: "helvetica",
        monospace: "monospace",
        sans: "helvetica"
    } });
function Example({ children }) {
    const theme = Providers_1.useTheme();
    return (react_1.jsx("div", { css: {
            background: theme.colors.background.default
        } },
        react_1.jsx("span", { css: {
                color: theme.colors.text.default
            } }, children)));
}
function Basic() {
    const theme = Providers_1.useTheme();
    return (react_1.jsx("div", null,
        react_1.jsx("span", { css: {
                color: theme.colors.text.selected
            } }, "Hello world, this is the default theme. You can compose modes:"),
        react_1.jsx(Providers_1.DarkMode, null,
            react_1.jsx("div", { css: { border: "1px solid", padding: "1rem" } },
                react_1.jsx(Example, null,
                    react_1.jsx("div", null,
                        react_1.jsx(Providers_1.LightMode, null, (theme) => (react_1.jsx("div", { css: {
                                background: theme.colors.background.default,
                                color: theme.colors.text.default
                            } }, "Using render callback, LightMode mode"))),
                        "This will be in DarkMode mode",
                        react_1.jsx(Providers_1.LightMode, null,
                            react_1.jsx(Example, null,
                                react_1.jsx("div", null, "But this will be in LightMode mode!")))))))));
}
exports.ThemeExamples = react_2.storiesOf("Theme", module)
    .add("Basic usage", () => react_1.jsx(Basic, null))
    .add("playground", () => (react_1.jsx("div", { css: { padding: "2rem" } },
    react_1.jsx(Layer_1.Layer, { css: { padding: "2rem" } },
        react_1.jsx(Popover_1.Popover, { content: react_1.jsx(Menu_1.MenuList, null,
                react_1.jsx(Menu_1.MenuItem, { onSelect: () => alert("Hello 1") }, "I will trigger an alert"),
                react_1.jsx(Menu_1.MenuItem, { component: "a", href: "/bacon" }, "I'm a link"),
                react_1.jsx(Menu_1.MenuDivider, null),
                react_1.jsx(Menu_1.MenuItem, null, "Item three")) },
            react_1.jsx(Button_1.Button, null, "I should trigger popover"))))))
    .add("Custom theme", () => {
    const sizes = ["xs", "sm", "md", "lg", "xl"];
    const appearance = ["default", "ghost", "outline"];
    const intents = [
        "none",
        "primary",
        "success",
        "danger",
        "warning"
    ];
    return (react_1.jsx("div", null,
        appearance.map(appearance => (react_1.jsx("div", { key: appearance }, sizes.map(size => (react_1.jsx("div", { key: size, style: { padding: "0.5rem" } }, intents.map(intent => (react_1.jsx(Button_1.Button, { key: size + appearance, size: size, css: {
                marginRight: "1rem",
                textTransform: "capitalize"
            }, variant: appearance, intent: intent, onClick: () => alert("hello there") }, intent))))))))),
        react_1.jsx("div", { css: {
                margin: "2rem",
                maxWidth: "38rem"
            } },
            react_1.jsx(Text_1.Text, { variant: "paragraph" },
                "Non proident est elit ",
                react_1.jsx(Link_1.Link, { href: "#" }, "aliqua reprehenderit"),
                ". Eu amet nostrud qui ex velit mollit velit eiusmod consequat aliquip enim et mollit. Sint eiusmod mollit Lorem et eiusmod exercitation anim esse."))));
})
    .add("contrast", () => {
    return react_1.jsx(ContrastExample, null);
})
    .add("DarkMode forwards ref", () => {
    return react_1.jsx(RefExample, null);
})
    .add("Tooltip with DarkMode wrrapper", () => {
    return (react_1.jsx(Tooltip_1.Tooltip, { content: "hello" },
        react_1.jsx(Providers_1.DarkMode, null,
            react_1.jsx(Button_1.Button, null, "Hello"))));
})
    .add("Works with IconButton", () => {
    return (react_1.jsx(Tooltip_1.Tooltip, { content: "hello" },
        react_1.jsx(Providers_1.LightMode, null,
            react_1.jsx(IconButton_1.IconButton, { variant: "ghost", label: "wtf", icon: react_1.jsx(Icons_1.IconArrowDown, null) }))));
});
function SampleTheme() {
    const theme = Providers_1.useTheme();
    return (react_1.jsx("div", { css: { background: theme.colors.palette.blue.base, padding: "3rem" } }));
}
function RefExample() {
    const ref = React.useRef();
    React.useEffect(() => {
        console.log(ref.current);
    }, []);
    return (react_1.jsx(Providers_1.DarkMode, { ref: ref },
        react_1.jsx(Button_1.Button, null, "Hello")));
}
function ContrastExample() {
    const theme = Providers_1.useTheme();
    const dark = theme.colors.mode === "dark";
    return (react_1.jsx("div", { css: { display: "flex" } },
        react_1.jsx("div", { css: {
                height: "400px",
                flex: "1 1 30%",
                background: dark
                    ? theme.colors.background.layer
                    : theme.colors.background.tint1
            } },
            react_1.jsx(Text_1.Text, null, "Hello")),
        react_1.jsx("div", { css: { flex: "1 1 70%" } }, "Basic")));
}
