/** @jsx jsx */
import { jsx } from "@emotion/react";
import * as React from "react";
import { Dialog } from "./Dialog";
import { Button } from "./Button";
import { useTheme } from "./Theme/Providers";
import { Text } from "./Text";
import { useUid } from "./Hooks/use-uid";
export const AlertDialog = ({ isOpen, title, subtitle, confirmLabel = "Confirm", onConfirm, intent = "danger", onCancel, onClose }) => {
    const theme = useTheme();
    const id = useUid();
    const cancel = React.useCallback(() => {
        if (onCancel)
            onCancel();
        onClose();
    }, [onCancel, onClose]);
    const confirm = React.useCallback(() => {
        onConfirm();
        onClose();
    }, [onConfirm]);
    return (jsx(Dialog, { role: "alertdialog", "aria-labelledby": id, onRequestClose: cancel, isOpen: isOpen },
        jsx("div", { css: { padding: "1.5rem" } },
            jsx(Text, { id: id, variant: "h5" }, title),
            subtitle && jsx(Text, null, subtitle),
            jsx("div", { css: {
                    marginTop: theme.spaces.md,
                    display: "flex",
                    justifyContent: "flex-end"
                } },
                jsx(Button, { autoFocus: true, onPress: cancel, variant: "ghost" }, "Cancel"),
                jsx(Button, { onPress: confirm, css: { marginLeft: theme.spaces.sm }, intent: intent }, confirmLabel)))));
};
