import { __rest } from "tslib";
/** @jsx jsx */
import { jsx } from "@emotion/react";
import * as React from "react";
import { Text } from "./Text";
import { CloseButton } from "./IconButton";
import { useTransition, animated } from "react-spring";
import { Overlay } from "./Overlay";
import { useFocusElement } from "./Hooks/use-focus-trap";
import PropTypes from "prop-types";
import useScrollLock from "use-scroll-lock";
import { useTheme } from "./Theme/Providers";
/**
 * A dialog is useful for displaying infomation that
 * commands the user's attention.
 */
export const Dialog = (_a) => {
    var { isOpen, onRequestClose, mobileFullscreen, title, children } = _a, other = __rest(_a, ["isOpen", "onRequestClose", "mobileFullscreen", "title", "children"]);
    const theme = useTheme();
    // [TransitionFn<Item, State & object>, SpringStartFn<State>, SpringStopFn<State>]
    const transitions = useTransition(isOpen, {
        from: { opacity: 0, transform: "scale(0.9)" },
        enter: { opacity: 1, transform: "scale(1)" },
        leave: { opacity: 0, transform: "scale(0.9)" },
        config: { mass: 1, tension: 185, friction: 26 }
    });
    const scrollableRef = React.useRef(null);
    const ref = React.useRef(null);
    useFocusElement(ref, isOpen);
    useScrollLock(isOpen, scrollableRef);
    return (jsx(React.Fragment, null,
        jsx(Overlay, { onRequestClose: onRequestClose, isOpen: isOpen },
            jsx(React.Fragment, null, transitions((style, item) => {
                return (item && jsx(animated.div, Object.assign({ key: 1, className: "Dialog", "aria-modal": "true", ref: ref, tabIndex: -1, onClick: (e) => {
                        e.stopPropagation();
                    }, style: {
                        opacity: style.opacity,
                        transform: style.transform
                    }, css: [
                        {
                            zIndex: theme.zIndices.modal,
                            background: theme.colors.background.default,
                            boxShadow: theme.shadows.md,
                            borderRadius: theme.radii.lg,
                            margin: "16px",
                            width: "calc(100% - 32px)",
                            outline: "none",
                            [theme.mediaQueries.md]: {
                                maxWidth: "500px",
                                margin: "30px auto"
                            },
                            [theme.mediaQueries.lg]: {
                                maxWidth: "650px",
                                margin: "30px auto"
                            }
                        },
                        mobileFullscreen && {
                            maxWidth: "none",
                            margin: 0,
                            width: "100vw",
                            height: "100vh",
                            borderRadius: 0,
                            boxShadow: "none",
                            [theme.mediaQueries.md]: {
                                maxWidth: "500px",
                                margin: "30px auto",
                                height: "auto",
                                boxShadow: theme.shadows.md,
                                borderRadius: theme.radii.lg,
                                width: "calc(100% - 32px)"
                            }
                        }
                    ] }, other),
                    jsx(React.Fragment, null,
                        title && (jsx(DialogHeader, { className: "Dialog__header", css: {
                                display: "flex",
                                justifyContent: "space-between",
                                alignItems: "center",
                                padding: `${theme.spaces.lg} ${theme.spaces.lg} 0 ${theme.spaces.lg}`
                            }, title: title, onRequestClose: onRequestClose })),
                        jsx("div", { ref: scrollableRef }, children))));
            })))));
};
Dialog.propTypes = {
    isOpen: PropTypes.bool.isRequired,
    onRequestClose: PropTypes.func.isRequired,
    title: PropTypes.string,
    mobileFullscreen: PropTypes.bool,
    children: PropTypes.node
};
export const DialogHeader = (_a) => {
    var { title, onRequestClose } = _a, other = __rest(_a, ["title", "onRequestClose"]);
    return (jsx("div", Object.assign({}, other),
        jsx(Text, { wrap: false, variant: "h4" }, title),
        onRequestClose && jsx(CloseButton, { onClick: onRequestClose })));
};
DialogHeader.propTypes = {
    title: PropTypes.string.isRequired,
    onRequestClose: PropTypes.func
};
