/** @jsx jsx */
import { jsx } from "@emotion/react";
import * as React from "react";
import { Alert } from "./Alert";
import PropTypes from "prop-types";
export class ErrorBoundary extends React.Component {
    constructor() {
        super(...arguments);
        this.state = {
            error: null
        };
    }
    componentDidCatch(error) {
        this.setState({ error });
    }
    render() {
        if (this.state.error) {
            //render error message
            return (jsx("div", { css: { padding: "1rem" } },
                jsx(Alert, { type: "assertive", intent: "danger", title: this.props.title, subtitle: this.props.subtitle })));
        }
        else {
            //when there's not an error, render children untouched
            return this.props.children;
        }
    }
}
ErrorBoundary.propTypes = {
    title: PropTypes.string,
    subtitle: PropTypes.string,
    children: PropTypes.node
};
ErrorBoundary.defaultProps = {
    title: "An unexpected error has occurred.",
    subtitle: "Please try reloading. If the problem persists, please contact us for help."
};
