import { __rest } from "tslib";
/** @jsx jsx */
import { jsx } from "@emotion/react";
import * as React from "react";
import { Button, getHeight } from "./Button";
import VisuallyHidden from "@reach/visually-hidden";
import PropTypes from "prop-types";
import { IconWrapper } from "./IconWrapper";
import { IconX } from "./Icons";
import { useTheme } from "./Theme/Providers";
/**
 * A component which composes Button and Icon to provide
 * interactive icon elements.
 */
export const IconButton = React.forwardRef((_a, ref) => {
    var { label, size = "md", icon, onPress, color = "currentColor" } = _a, other = __rest(_a, ["label", "size", "icon", "onPress", "color"]);
    const theme = useTheme();
    return (jsx(Button, Object.assign({ ref: ref, size: size, css: {
            padding: 0,
            [theme.mediaQueries.sm]: {
                padding: 0,
            },
            [theme.mediaQueries.lg]: {
                padding: 0,
            },
            width: getHeight(size)
        }, onPress: onPress }, other),
        jsx(VisuallyHidden, null, label),
        jsx(IconWrapper, { color: color, size: size }, icon)));
});
IconButton.displayName = "IconButton";
IconButton.propTypes = {
    icon: PropTypes.node.isRequired,
    color: PropTypes.string,
    label: PropTypes.string.isRequired,
    variant: PropTypes.oneOf(["outline", "default", "ghost"]),
    size: PropTypes.oneOf(["xs", "sm", "md", "lg", "xl"])
};
export const CloseButton = (_a) => {
    var { label = "Close" } = _a, other = __rest(_a, ["label"]);
    return (jsx(IconButton, Object.assign({ variant: "ghost", label: label, icon: jsx(IconX, null) }, other)));
};
CloseButton.propTypes = {
    label: PropTypes.string,
    color: PropTypes.string,
    variant: PropTypes.oneOf(["outline", "default", "ghost"]),
    size: PropTypes.oneOf(["xs", "sm", "md", "lg", "xl"])
};
