import { __rest } from "tslib";
/** @jsx jsx */
import { jsx } from "@emotion/react";
import { Text } from "./Text";
import PropTypes from "prop-types";
import { MenuLabel } from "./Menu";
import { useTheme } from "./Theme/Providers";
import { noOp } from "./misc/noop";
import { useTouchable } from "touchable-hook";
import { safeBind } from "./Hooks/compose-bind";
export const List = (_a) => {
    var { children } = _a, other = __rest(_a, ["children"]);
    return jsx("nav", Object.assign({}, other), children);
};
List.propTypes = {
    children: PropTypes.node
};
export const ListItem = (_a) => {
    var { primary, secondary, contentBefore, interactive = true, children, wrap = true, contentAfter, onPress = noOp, component: Component = "div" } = _a, other = __rest(_a, ["primary", "secondary", "contentBefore", "interactive", "children", "wrap", "contentAfter", "onPress", "component"]);
    const interactiveProps = interactive
        ? {
            role: "button",
            tabIndex: 0
        }
        : {};
    const isLink = other.to || other.href;
    const { bind, hover, active } = useTouchable({
        onPress,
        behavior: isLink ? "link" : "button"
    });
    const theme = useTheme();
    return (jsx(Component, Object.assign({ className: "ListItem", css: [
            {
                display: "block",
                textDecoration: "none",
                outline: "none",
                padding: theme.spaces.md,
                background: "transparent",
                WebkitTapHighlightColor: "transparent",
                transition: "background 0.07s ease",
                [theme.mediaQueries.lg]: {
                    paddingLeft: theme.spaces.lg,
                    paddingRight: theme.spaces.lg
                },
                ":last-child": {
                    borderBottom: "none"
                }
            },
            interactive && {
                cursor: "pointer",
                ":focus": {
                    boxShadow: `inset 0 0 3px ${theme.colors.text.selected}`
                },
                ":focus:not([data-focus-visible-added])": {
                    boxShadow: "none"
                }
            },
            interactive &&
                hover && {
                background: theme.colors.background.tint1
            },
            interactive &&
                active && {
                background: theme.colors.background.tint2
            }
        ] }, interactiveProps, safeBind(interactive ? bind : {}, other)),
        jsx("div", { className: "ListItem__container", css: { display: "flex", alignItems: "center" } },
            contentBefore && (jsx("div", { className: "ListItem__content-before", css: { marginRight: theme.spaces.md } }, contentBefore)),
            jsx("div", { className: "ListItem__content", css: { flex: 1, overflow: "hidden" } },
                jsx(Text, { className: "ListItem__primary", wrap: wrap, variant: "body", css: { display: "block", fontWeight: 500 } }, primary),
                secondary && (jsx(Text, { className: "ListItem__secondary", wrap: wrap, css: { display: "block", fontSize: theme.fontSizes[0] }, variant: "body", muted: true }, secondary)),
                children),
            contentAfter && (jsx("div", { className: "ListItem__content-after", css: { flex: "0 0 auto", marginLeft: theme.spaces.md } }, contentAfter)))));
};
ListItem.propTypes = {
    primary: PropTypes.oneOfType([PropTypes.string, PropTypes.node]).isRequired,
    secondary: PropTypes.oneOfType([PropTypes.string, PropTypes.node]),
    contentBefore: PropTypes.node,
    contentAfter: PropTypes.node,
    wrap: PropTypes.bool,
    children: PropTypes.node,
    interactive: PropTypes.bool,
    onPress: PropTypes.func,
    component: PropTypes.elementType
};
export const ListSection = (_a) => {
    var { title, children, sticky = true } = _a, other = __rest(_a, ["title", "children", "sticky"]);
    const theme = useTheme();
    const bg = theme.colors.background.layer;
    return (jsx("div", { css: {
            ":first-child > *": {
                borderTop: "none"
            }
        } },
        jsx(MenuLabel, Object.assign({ css: {
                position: sticky ? "sticky" : "static",
                top: 0,
                backgroundColor: sticky ? bg : "transparent",
                padding: theme.spaces.sm,
                paddingLeft: theme.spaces.md,
                marginTop: theme.spaces.md,
                [theme.mediaQueries.lg]: {
                    paddingLeft: theme.spaces.lg,
                    paddingRight: theme.spaces.lg
                }
            } }, other), title),
        children));
};
ListSection.propTypes = {
    title: PropTypes.string.isRequired,
    sticky: PropTypes.bool,
    children: PropTypes.node
};
