import { __rest } from "tslib";
/** @jsx jsx */
import { jsx, css, keyframes } from "@emotion/react";
import * as React from "react";
import VisuallyHidden from "@reach/visually-hidden";
import PropTypes from "prop-types";
import { Text } from "./Text";
import { useTheme } from "./Theme/Providers";
const spin = keyframes `
  to { 
    transform: rotate(360deg); 
  }
`;
const sizeStyles = {
    xs: css({ width: "0.5rem", height: "0.5rem" }),
    sm: css({ width: "0.75rem", height: "0.75rem" }),
    md: css({ width: "1rem", height: "1rem" }),
    lg: css({ width: "1.25rem", height: "1.25rem" }),
    xl: css({ width: "1.5rem", height: "1.5rem" })
};
// spinner css based on one provided by bootstrap
// https://getbootstrap.com/docs/4.3/components/spinners/
export const Spinner = (_a) => {
    var { delay = 400, size = "md", center, label } = _a, other = __rest(_a, ["delay", "size", "center", "label"]);
    const theme = useTheme();
    const [show, setShow] = React.useState(delay === 0 ? true : false);
    React.useEffect(() => {
        const timer = setTimeout(() => {
            setShow(true);
        }, delay);
        return () => {
            clearTimeout(timer);
        };
    }, [delay]);
    return (jsx("div", Object.assign({ className: "Spinner", css: [
            {
                opacity: show ? 1 : 0,
                display: "inline-block",
                transition: "opacity 0.4s cubic-bezier(0.35,0,0.25,1)"
            },
            center && {
                width: "100%",
                height: "100%",
                boxSizing: "border-box",
                display: "flex",
                alignItems: "center",
                alignSelf: "center",
                justifyContent: "center"
            }
        ] }, other),
        jsx("div", { className: "Spinner__container", role: "status", css: {
                color: theme.colors.text.default,
                textAlign: "center",
                display: "inline-block"
            } },
            jsx("div", { className: "Spinner__spinner", css: [
                    css `
              display: inline-block;
              vertical-align: text-bottom;
              border: 0.15em solid currentColor;
              border-right-color: transparent;
              border-radius: 50%;
              animation: ${spin} 0.75s linear infinite;
            `,
                    sizeStyles[size]
                ] }),
            label ? (jsx(Text, { className: "Spinner__label", wrap: false, css: { display: "block", marginTop: theme.spaces.sm }, variant: "subtitle" }, label)) : (jsx(VisuallyHidden, null, "Loading")))));
};
Spinner.propTypes = {
    delay: PropTypes.number,
    center: PropTypes.bool,
    label: PropTypes.string,
    size: PropTypes.oneOf(["xs", "sm", "md", "lg", "xl"])
};
