import { __rest } from "tslib";
/** @jsx jsx */
import { jsx, css } from "@emotion/react";
import * as React from "react";
import { Layer } from "./Layer";
import PropTypes from "prop-types";
import { useTheme } from "./Theme/Providers";
const TableSectionContext = React.createContext({
    type: "TableHead"
});
const TableContext = React.createContext({ fixed: false });
export const Table = (_a) => {
    var { children, minWidth, fixed } = _a, other = __rest(_a, ["children", "minWidth", "fixed"]);
    const theme = useTheme();
    return (jsx("div", { css: {
            width: "100%",
            display: "block",
            overflowX: minWidth ? "auto" : "initial"
        } },
        jsx("table", Object.assign({ css: {
                borderSpacing: 0,
                borderCollapse: "separate",
                width: "100%",
                fontFamily: theme.fonts.base,
                WebkitAppearance: "none",
                WebkitFontSmoothing: "antialiased",
                display: "table",
                minWidth,
                tableLayout: fixed ? "fixed" : undefined
            } }, other),
            fixed && (jsx("colgroup", null, fixed.map((width, i) => {
                return jsx("col", { key: i, width: width });
            }))),
            jsx(TableContext.Provider, { value: { fixed: fixed ? true : false } }, children))));
};
Table.propTypes = {
    minWidth: PropTypes.string,
    fixed: PropTypes.arrayOf(PropTypes.string),
    children: PropTypes.node
};
export function TableHead(_a) {
    var { children } = _a, other = __rest(_a, ["children"]);
    return (jsx("thead", Object.assign({ css: {
            display: "table-header-group"
        } }, other),
        jsx(TableSectionContext.Provider, { value: { type: "TableHead" } }, children)));
}
export const TableRow = (_a) => {
    var { onClick, children } = _a, other = __rest(_a, ["onClick", "children"]);
    const theme = useTheme();
    const { type: tableSectionType } = React.useContext(TableSectionContext);
    const buttonProps = onClick
        ? {
            role: "button",
            tabIndex: 0
        }
        : {};
    return (jsx("tr", Object.assign({ onClick: onClick, css: {
            height: tableSectionType === "TableHead" ? "31px" : "49px",
            display: "table-row",
            outline: "none",
            verticalAlign: "middle",
            cursor: onClick ? "pointer" : "default",
            ":hover": {
                background: onClick ? theme.colors.background.tint1 : "none"
            }
        } }, buttonProps, other), children));
};
TableRow.propTypes = {
    onClick: PropTypes.func,
    children: PropTypes.node
};
/**
 * TableCell, used for both <td> and <th> elements.
 */
const tableCellAlignments = {
    right: css({
        textAlign: "right",
        flexDirection: "row-reverse"
    }),
    left: css({
        textAlign: "left"
    }),
    center: css({
        textAlign: "center"
    }),
    justify: css({
        textAlign: "justify"
    })
};
export const TableCell = (_a) => {
    var { align = "left", variant, component, ellipsis, children } = _a, other = __rest(_a, ["align", "variant", "component", "ellipsis", "children"]);
    const theme = useTheme();
    const { type: tableSectionType } = React.useContext(TableSectionContext);
    const Component = component || (tableSectionType === "TableHead" ? "th" : "td");
    const type = variant || (tableSectionType === "TableHead" ? "head" : "body");
    return (jsx(Component, Object.assign({ css: [
            {
                zIndex: 4,
                position: "relative",
                borderBottom: "1px solid",
                borderColor: tableSectionType === "TableBody"
                    ? theme.colors.border.muted
                    : theme.colors.border.default,
                display: "table-cell",
                padding: `${theme.spaces.xs} ${theme.spaces.sm}`,
                [theme.mediaQueries.lg]: {
                    paddingLeft: theme.spaces.md,
                    paddingRight: theme.spaces.md
                },
                ":last-child": {
                    paddingRight: theme.spaces.md
                }
            },
            ellipsis && {
                whiteSpace: "nowrap",
                textOverflow: "ellipsis",
                overflow: "hidden"
            },
            type === "head"
                ? {
                    fontWeight: 500,
                    fontSize: theme.fontSizes[0],
                    color: theme.colors.text.muted
                }
                : {
                    fontWeight: 400,
                    fontSize: theme.fontSizes[0],
                    color: theme.colors.text.default
                },
            tableCellAlignments[align]
        ], scope: "col" }, other), children));
};
TableCell.propTypes = {
    align: PropTypes.oneOf(Object.keys(tableCellAlignments)),
    variant: PropTypes.oneOf(["body", "head"]),
    component: PropTypes.elementType,
    ellipsis: PropTypes.bool,
    children: PropTypes.node
};
export function TableBody(_a) {
    var { children } = _a, other = __rest(_a, ["children"]);
    return (jsx("tbody", Object.assign({ css: {
            display: "table-row-group"
        } }, other),
        jsx(TableSectionContext.Provider, { value: { type: "TableBody" } }, children)));
}
export const ExpandingRow = ({ content, children }) => {
    const theme = useTheme();
    const [selected, setSelected] = React.useState(false);
    function close() {
        setSelected(false);
    }
    function open() {
        setSelected(true);
    }
    return (jsx(TableBody, null,
        jsx(TableRow, { onClick: open }, children),
        selected && (jsx("tr", { css: { display: "table-row", height: "100px" } },
            jsx("td", { colSpan: React.Children.count(children), css: {
                    borderBottom: 0,
                    width: "inherit",
                    padding: 0,
                    position: "relative"
                } },
                jsx("div", { css: {
                        zIndex: 3,
                        width: "inherit",
                        position: "relative",
                        paddingBottom: "24px"
                    } },
                    jsx("div", { css: {
                            position: "relative",
                            whiteSpace: "normal",
                            height: "auto",
                            display: "block",
                            paddingTop: "24px"
                        } }, typeof content === "function" ? content(close) : content)),
                jsx(Layer, { css: {
                        position: "absolute",
                        top: "-49px",
                        left: "-16px",
                        right: "-16px",
                        borderRadius: theme.radii.md,
                        bottom: 0,
                        zIndex: 2
                    } }, null))))));
};
ExpandingRow.propTypes = {
    content: PropTypes.oneOfType([PropTypes.func, PropTypes.node]),
    children: PropTypes.node
};
