/** @jsx jsx */
import { jsx, Global, css } from "@emotion/react";
import * as React from "react";
import toaster from "toasted-notes";
import { Alert } from "./Alert";
import { useTheme, ThemeProvider } from "./Theme/Providers";
const toastStyles = css `
  .Toaster__message-wrapper {
    padding: 8px;
    text-align: left;
  }
`;
/**
 * We export toast as a hook because it allows us to consume
 * the current theme context that it's in and pass that
 * onto our render function
 */
export function useToast() {
    const theme = useTheme();
    function notify({ position, duration, render, title, subtitle, intent }) {
        const options = {
            position,
            duration
        };
        if (render) {
            return toaster.notify(({ onClose, id }) => (jsx(React.Fragment, null,
                jsx(Global, { styles: toastStyles }),
                jsx(ThemeProvider, { theme: theme }, render({ onClose, id })))), options);
        }
        toaster.notify(({ onClose, id }) => (jsx(React.Fragment, null,
            jsx(Global, { styles: toastStyles }),
            jsx(ThemeProvider, { theme: theme },
                jsx(Alert, { id: String(id), title: title, component: "div", elevation: "md", subtitle: subtitle, intent: intent, onRequestClose: onClose })))), options);
    }
    return notify;
}
