/** @jsx jsx */
import { jsx } from "@emotion/react";
import * as React from "react";
import { Avatar } from "../Avatar";
import faker from "faker";
import { storiesOf } from "@storybook/react";
import { ComboBox, ComboBoxInput, ComboBoxList, ComboBoxOption, ComboBoxOptionText } from "../ComboBox";
import { InputBase } from "../Form";
import { Text } from "../Text";
import { ListItem } from "../List";
export const ComboBoxStories = storiesOf("ComboBox", module)
    .add("basic", () => {
    return jsx(Example, null);
})
    .add("list item", () => jsx(CustomExample, null));
const defaultEntries = new Array(100).fill(null).map(() => ({
    id: faker.random.uuid(),
    name: faker.name.firstName() + " " + faker.name.lastName(),
    image: faker.image.avatar()
}));
function Example() {
    const [entries, setEntries] = React.useState(defaultEntries);
    const [query, setQuery] = React.useState("");
    const toRender = !query
        ? []
        : entries
            .filter(entry => entry.name.toLowerCase().indexOf(query.toLowerCase()) > -1)
            .slice(0, 10);
    return (jsx("div", { css: { margin: "3rem auto", width: "30rem" } },
        jsx(ComboBox, { autocomplete: true, query: query, onQueryChange: v => {
                setQuery(v);
            }, onSelect: v => {
                setQuery(v);
            } },
            jsx(ComboBoxInput, { "aria-label": "Query users", placeholder: "Search for users" }),
            query && (jsx(ComboBoxList, { "aria-label": "Query users" }, toRender.length ? (toRender.map(entry => {
                return jsx(ComboBoxOption, { value: entry.name, key: entry.id });
            })) : (jsx("div", null,
                jsx(Text, { muted: true, css: { display: "block", padding: "0.5rem 0.75rem" } }, query && toRender.length === 0 ? (jsx("span", null, "No entries found.")) : (jsx("span", null, "Try searching for users by email or name."))))))))));
}
function CustomExample() {
    const [entries, setEntries] = React.useState(defaultEntries);
    const [query, setQuery] = React.useState("");
    const toRender = !query
        ? []
        : entries
            .filter(entry => entry.name.toLowerCase().indexOf(query.toLowerCase()) > -1)
            .slice(0, 8);
    return (jsx("div", { css: { margin: "3rem auto", width: "30rem" } },
        jsx(ComboBox, { query: query, onQueryChange: v => {
                setQuery(v);
            }, onSelect: v => {
                setQuery(v);
            } },
            jsx(ComboBoxInput, { "aria-label": "Query users", placeholder: "Search for users", component: InputBase, autocomplete: true }),
            query && (jsx(ComboBoxList, { "aria-label": "Query users" }, toRender.length ? (toRender.map(entry => {
                return (jsx(ComboBoxOption, { css: { padding: 0 }, value: entry.name, key: entry.id },
                    jsx(ListItem, { interactive: false, primary: jsx(ComboBoxOptionText, { value: entry.name }), contentBefore: jsx(Avatar, { size: "sm", name: entry.name, src: entry.image }) })));
            })) : (jsx("div", null,
                jsx(Text, { muted: true, css: { display: "block", padding: "0.5rem 0.75rem" } }, query && toRender.length === 0 ? (jsx("span", null, "No entries found.")) : (jsx("span", null, "Try searching for users by email or name."))))))))));
}
