/** @jsx jsx */
import { jsx } from "@emotion/react";
import * as React from "react";
import { storiesOf } from "@storybook/react";
import { useInfiniteScroll } from "../Hooks/use-infinite-scroll";
import * as faker from "faker";
import { ScrollView } from "../ScrollView";
import { List, ListItem } from "../List";
import { Skeleton } from "../Skeleton";
import { Avatar } from "../Avatar";
import { Layer } from "../Layer";
import { IconChevronRight } from "../Icons";
import { useTheme } from "../Theme/Providers";
function fetchdata() {
    return new Promise(resolve => {
        setTimeout(() => {
            resolve(void 0);
        }, 800);
    });
}
function getUser() {
    faker.seed(0);
    return {
        name: faker.name.firstName() + " " + faker.name.lastName(),
        uid: faker.random.uuid(),
        description: faker.lorem.sentence()
    };
}
function Example() {
    const theme = useTheme();
    const ref = React.useRef(null);
    const [items, setItems] = React.useState(Array.from(new Array(10)).map(() => getUser()));
    const [page, setPage] = React.useState(0);
    const [fetching] = useInfiniteScroll({
        container: ref,
        hasMore: page < 4,
        onFetch: () => {
            return fetchdata().then(() => {
                setItems([...items, ...Array.from(new Array(10)).map(() => getUser())]);
                setPage(page + 1);
            });
        }
    });
    return (jsx(Layer, { css: {
            width: "400px",
            overflow: "hidden"
        } },
        jsx(ScrollView, { css: {
                height: "280px"
            }, overflowY: true, innerRef: ref },
            jsx(List, null,
                items.map(item => (jsx(ListItem, { key: item.uid, contentBefore: jsx(Avatar, { name: item.name }), primary: item.name, secondary: item.description, contentAfter: jsx(IconChevronRight, { color: theme.colors.text.muted }) }))),
                fetching && (jsx(ListItem, { interactive: false, "aria-live": "polite", "aria-busy": "true", primary: jsx(Skeleton, { animated: true, css: { width: "100px" } }), secondary: jsx(Skeleton, { animated: true }), contentBefore: jsx(Skeleton, { animated: true, css: {
                            width: "3.27rem",
                            height: "3.27rem",
                            borderRadius: "50%"
                        } }) }))))));
}
function WindowExample() {
    const [items, setItems] = React.useState(Array.from(new Array(10)).map(() => faker.name.firstName()));
    const [page, setPage] = React.useState(0);
    const [fetching] = useInfiniteScroll({
        hasMore: page < 4,
        onFetch: () => {
            return fetchdata().then(() => {
                setItems([
                    ...items,
                    ...Array.from(new Array(10)).map(() => faker.name.firstName())
                ]);
                setPage(page + 1);
            });
        }
    });
    return (jsx("div", null,
        items.map(item => (jsx("div", { css: { height: "40px", border: "1px solid" }, key: item }, item))),
        fetching && jsx("div", null, "Loading...")));
}
export const ThemeExamples = storiesOf("InfiniteScroll", module)
    .add("Basic usage", () => (jsx("div", { css: { padding: "1rem" } },
    jsx(Example, null))))
    .add("Window scroll", () => jsx(WindowExample, null));
