/** @jsx jsx */
import { jsx } from "@emotion/react";
import * as React from "react";
import { Layer, LayerLoading } from "../Layer";
import { storiesOf } from "@storybook/react";
import theme from "../Theme";
import { Button } from "../Button";
import { DarkMode } from "../Theme/Providers";
import { Text } from "../Text";
import { Tooltip } from "../Tooltip";
import { Popover } from "../Popover";
import { MenuList, MenuItem, MenuDivider } from "../Menu";
export const LayerStories = storiesOf("Layer", module)
    .add("Elevation options", () => {
    const elevations = ["xs", "sm", "md", "lg"];
    return (jsx("div", null, elevations.map(e => (jsx(Layer, { css: {
            marginLeft: "auto",
            marginRight: "auto",
            width: "400px",
            height: "200px",
            display: "flex",
            justifyContent: "center",
            alignItems: "center",
            marginBottom: "2rem"
        }, elevation: e },
        jsx(Tooltip, { content: "This is some tooltip content" },
            jsx(Button, { variant: "outline" }, "Hello world. Hover me!!")),
        ["auto"].map(placement => (jsx("div", { css: { marginTop: "1rem", textAlign: "center" }, key: placement },
            jsx(Popover, { placement: placement, content: jsx(MenuList, null,
                    jsx(MenuItem, { onSelect: () => alert("Hello 1") }, "I will trigger an alert"),
                    jsx(MenuItem, { component: "a", href: "/bacon" }, "I'm a link"),
                    jsx(MenuDivider, null),
                    jsx(MenuItem, null, "Item three")) },
                jsx(Button, null, placement))))))))));
})
    .add("Loading", () => {
    return jsx(Loading, null);
})
    .add("Dark", () => {
    return (jsx(DarkMode, null,
        jsx(Layer, { css: {
                padding: "2rem",
                width: "400px",
                height: "200px",
                marginBottom: "2rem"
            }, elevation: "md" },
            jsx(Text, null, "Hello world. This is dark mode."),
            jsx(LayerLoading, { label: "Loading in the dark", loading: true }))));
});
function Loading() {
    const [loading, setLoading] = React.useState(false);
    React.useEffect(() => {
        setTimeout(() => {
            setLoading(false);
        }, 4000);
    }, [loading]);
    return (jsx("div", { css: {
            background: theme.colors.background.tint2,
            padding: "3rem"
        } },
        jsx(Layer, { css: {
                width: "400px",
                height: "400px",
                display: "flex",
                flexDirection: "column",
                justifyContent: "center",
                alignItems: "center"
            } },
            jsx(Button, { onClick: () => setLoading(true) }, "Trigger loading"),
            jsx(LayerLoading, { loading: loading }))));
}
