/** @jsx jsx */
import { jsx } from "@emotion/react";
import * as React from "react";
import { Popover, ResponsivePopover } from "../Popover";
import { Button } from "../Button";
import { MenuList, MenuItem, MenuDivider } from "../Menu";
import { IconButton } from "../IconButton";
import { storiesOf } from "@storybook/react";
import { IconMoreHorizontal, IconUser, IconPackage, IconMapPin, IconActivity, IconArrowUpRight } from "../Icons";
const Link = React.forwardRef((props, ref) => (jsx("div", Object.assign({ ref: ref, css: {
        ":focus": {
            backgroundColor: "blue"
        }
    } }, props), props.children)));
export const PopoverStories = storiesOf("Popover", module)
    .add("Focus management", () => {
    return (jsx("div", null,
        jsx("div", { css: { padding: "300px", background: "#eee" } },
            jsx(Popover, { content: jsx("div", { css: { padding: "2rem" } },
                    jsx(Button, null, "I should focus")) },
                jsx(Button, null, "Hello world!")))));
})
    .add("positions", () => {
    return (jsx("div", null, [
        "auto-start",
        "auto",
        "auto-end",
        "top-start",
        "top",
        "top-end",
        "right-start",
        "right",
        "right-end",
        "bottom-end",
        "bottom",
        "bottom-start",
        "left-end",
        "left",
        "left-start"
    ].map(placement => (jsx("div", { css: { marginTop: "1rem", textAlign: "center" }, key: placement },
        jsx(Popover, { placement: placement, content: jsx(MenuList, null,
                jsx(MenuItem, { onSelect: () => alert("Hello 1") }, "I will trigger an alert"),
                jsx(MenuItem, { component: "a", href: "/bacon" }, "I'm a link"),
                jsx(MenuDivider, null),
                jsx(MenuItem, null, "Item three")) },
            jsx(Button, null, placement)))))));
})
    .add("Dropdown menu", () => {
    return (jsx("div", { css: { padding: "300px", minHeight: "80vh" } },
        jsx(Popover, { content: jsx(MenuList, null,
                jsx(MenuItem, { onPress: () => alert("Hello 1") }, "I will trigger an alert"),
                jsx(MenuItem, { component: "a", href: "/bacon" }, "I'm a link"),
                jsx(MenuDivider, null),
                jsx(MenuItem, null, "Item three")) },
            jsx(Button, null, "I should trigger popover"))));
})
    .add("Triggered with an icon button", () => {
    return (jsx("div", { css: { padding: "300px", minHeight: "150vh", background: "#eee" } },
        jsx(Popover, { content: jsx(MenuList, null,
                jsx(MenuItem, { onSelect: () => alert("Hello 1") }, "Item one"),
                jsx(MenuItem, null, "Item three"),
                jsx(MenuDivider, null),
                jsx(MenuItem, null, "Item three"),
                jsx(MenuItem, null, "Item three"),
                jsx(MenuItem, null, "Item three")) },
            jsx(IconButton, { variant: "ghost", icon: jsx(IconMoreHorizontal, null), label: "show more" }))));
})
    .add("ResponsivePopover", () => {
    return (jsx("div", { css: { padding: "1rem" } },
        jsx(ResponsivePopover, { content: jsx(MenuList, null,
                jsx(MenuItem, { contentBefore: jsx(IconUser, null), onSelect: () => alert("Hello 1") }, "Drink coffee"),
                jsx(MenuItem, { contentBefore: jsx(IconPackage, null) }, "Eat pancakes"),
                jsx(MenuDivider, null),
                jsx(MenuItem, { contentBefore: jsx(IconMapPin, null) }, "Make pizza"),
                jsx(MenuItem, { contentBefore: jsx(IconActivity, null) }, "Dance my heart out"),
                jsx(MenuItem, { contentBefore: jsx(IconArrowUpRight, null) }, "Anything you ask")) },
            jsx(IconButton, { variant: "ghost", icon: jsx(IconMoreHorizontal, null), label: "show more" }))));
});
