/** @jsx jsx */
import { jsx } from "@emotion/react";
import * as React from "react";
import { storiesOf } from "@storybook/react";
import { Sheet } from "../Sheet";
import { Button } from "../Button";
import { MenuList, MenuItem, MenuDivider } from "../Menu";
export const SheetExamples = storiesOf("Sheet", module)
    .add("basic example", () => {
    return (jsx(Example, { position: "left", label: "hi" },
        jsx("div", null,
            "Helloooo world!",
            jsx("button", null, "one"),
            jsx("button", null, "two"),
            jsx("button", null, "tjree"),
            jsx("button", null, "four"),
            jsx("div", { "data-scroll-lock-scrollable": true, style: {
                    border: "1px solid",
                    width: "100px",
                    height: "100px",
                    overflow: "scroll"
                } },
                jsx("div", { style: { height: "200px" } }, "scrollable")))));
})
    .add("Different positions", () => {
    const positions = ["top", "left", "right", "bottom"];
    const examples = positions.map(position => {
        return (jsx(React.Fragment, { key: position },
            jsx(Example, { position: position, label: position },
                jsx("div", null,
                    "Helloooo world!",
                    jsx("button", null, "one"),
                    jsx("button", null, "two"),
                    jsx("button", null, "tjree"),
                    jsx("button", null, "four")))));
    });
    return (jsx("div", { css: {
            display: "flex",
            justifyContent: "center",
            flexDirection: "column",
            alignItems: "center",
            height: "100%",
            "& > *": {
                margin: "1rem",
                width: "200px"
            }
        } }, examples));
})
    .add("Sheet menu", () => {
    return (jsx(Example, { position: "bottom" },
        jsx(MenuList, { css: { display: "block" } },
            jsx(MenuItem, null, "Hello world number 1"),
            jsx(MenuItem, null, "Hello world number 2"),
            jsx(MenuItem, { disabled: true }, "Hello world number 2"),
            jsx(MenuItem, { onSelect: () => {
                    alert("selected!");
                } }, "try selecting me"),
            jsx(MenuItem, null, "Hello world number 2"),
            jsx(MenuDivider, null),
            jsx(MenuItem, null, "Hello world number 2"),
            jsx(MenuItem, null, "Hello world number 2"))));
})
    .add("Scroll lock", () => {
    return (jsx(Example, { position: "bottom" },
        jsx(MenuList, { css: { display: "block" } },
            jsx(MenuItem, null, "Hello world number 1"),
            jsx(MenuItem, null, "Hello world number 2"),
            jsx(MenuItem, { disabled: true }, "Hello world number 2"),
            jsx(MenuItem, { onSelect: () => {
                    alert("selected!");
                } }, "try selecting me"),
            jsx(MenuItem, null, "Hello world number 2"),
            jsx(MenuDivider, null),
            jsx(MenuItem, null, "Hello world number 2"),
            jsx(MenuItem, null, "Hello world number 2"))));
})
    .add("vertical swipe test", () => {
    return (jsx(Example, { position: "top" },
        jsx(MenuList, { css: { display: "block" } },
            jsx(MenuItem, null, "Hello world number 1"),
            jsx(MenuItem, null, "Hello world number 2"),
            jsx(MenuItem, { disabled: true }, "Hello world number 2"),
            jsx(MenuItem, { onSelect: () => {
                    alert("selected!");
                } }, "try selecting me"),
            jsx(MenuItem, null, "Hello world number 2"),
            jsx(MenuDivider, null),
            jsx(MenuItem, null, "Hello world number 2"),
            jsx(MenuItem, null, "Hello world number 2"))));
});
const Example = ({ label = "show", position = "left", children }) => {
    const [show, setShow] = React.useState(false);
    return (jsx("div", { css: {
            minHeight: "150vh"
        } },
        jsx(Button, { onPress: () => setShow(true) }, label),
        jsx(Sheet, { onRequestClose: () => setShow(false), isOpen: show, position: position }, children)));
};
