/** @jsx jsx */
import { jsx } from "@emotion/react";
import { storiesOf } from "@storybook/react";
import { useTheme, DarkMode, LightMode } from "../Theme/Providers";
import defaultTheme from "../Theme";
import { Layer } from "../Layer";
import { Popover } from "../Popover";
import { MenuList, MenuDivider, MenuItem } from "../Menu";
import { Button } from "../Button";
import { Text } from "../Text";
import palx from "palx";
import { Link } from "../Link";
import * as React from "react";
import { generateColorsFromScales } from "../Theme/colors";
import { Tooltip } from "../Tooltip";
import { IconButton } from "../IconButton";
import { IconArrowDown } from "../Icons";
const customPalette = palx("#007bff");
const colors = generateColorsFromScales(customPalette, {
// generateIntents
});
// function generateIntents(palette: PaletteType) {
//   return {
//     none: palette.gray,
//     primary: palette.teal,
//     success: palette.violet,
//     danger: palette.red,
//     warning: palette.yellow
//   };
// }
const custom = Object.assign(Object.assign(Object.assign({}, defaultTheme), colors), { fonts: {
        base: "helvetica",
        monospace: "monospace",
        sans: "helvetica"
    } });
function Example({ children }) {
    const theme = useTheme();
    return (jsx("div", { css: {
            background: theme.colors.background.default
        } },
        jsx("span", { css: {
                color: theme.colors.text.default
            } }, children)));
}
function Basic() {
    const theme = useTheme();
    return (jsx("div", null,
        jsx("span", { css: {
                color: theme.colors.text.selected
            } }, "Hello world, this is the default theme. You can compose modes:"),
        jsx(DarkMode, null,
            jsx("div", { css: { border: "1px solid", padding: "1rem" } },
                jsx(Example, null,
                    jsx("div", null,
                        jsx(LightMode, null, (theme) => (jsx("div", { css: {
                                background: theme.colors.background.default,
                                color: theme.colors.text.default
                            } }, "Using render callback, LightMode mode"))),
                        "This will be in DarkMode mode",
                        jsx(LightMode, null,
                            jsx(Example, null,
                                jsx("div", null, "But this will be in LightMode mode!")))))))));
}
export const ThemeExamples = storiesOf("Theme", module)
    .add("Basic usage", () => jsx(Basic, null))
    .add("playground", () => (jsx("div", { css: { padding: "2rem" } },
    jsx(Layer, { css: { padding: "2rem" } },
        jsx(Popover, { content: jsx(MenuList, null,
                jsx(MenuItem, { onSelect: () => alert("Hello 1") }, "I will trigger an alert"),
                jsx(MenuItem, { component: "a", href: "/bacon" }, "I'm a link"),
                jsx(MenuDivider, null),
                jsx(MenuItem, null, "Item three")) },
            jsx(Button, null, "I should trigger popover"))))))
    .add("Custom theme", () => {
    const sizes = ["xs", "sm", "md", "lg", "xl"];
    const appearance = ["default", "ghost", "outline"];
    const intents = [
        "none",
        "primary",
        "success",
        "danger",
        "warning"
    ];
    return (jsx("div", null,
        appearance.map(appearance => (jsx("div", { key: appearance }, sizes.map(size => (jsx("div", { key: size, style: { padding: "0.5rem" } }, intents.map(intent => (jsx(Button, { key: size + appearance, size: size, css: {
                marginRight: "1rem",
                textTransform: "capitalize"
            }, variant: appearance, intent: intent, onClick: () => alert("hello there") }, intent))))))))),
        jsx("div", { css: {
                margin: "2rem",
                maxWidth: "38rem"
            } },
            jsx(Text, { variant: "paragraph" },
                "Non proident est elit ",
                jsx(Link, { href: "#" }, "aliqua reprehenderit"),
                ". Eu amet nostrud qui ex velit mollit velit eiusmod consequat aliquip enim et mollit. Sint eiusmod mollit Lorem et eiusmod exercitation anim esse."))));
})
    .add("contrast", () => {
    return jsx(ContrastExample, null);
})
    .add("DarkMode forwards ref", () => {
    return jsx(RefExample, null);
})
    .add("Tooltip with DarkMode wrrapper", () => {
    return (jsx(Tooltip, { content: "hello" },
        jsx(DarkMode, null,
            jsx(Button, null, "Hello"))));
})
    .add("Works with IconButton", () => {
    return (jsx(Tooltip, { content: "hello" },
        jsx(LightMode, null,
            jsx(IconButton, { variant: "ghost", label: "wtf", icon: jsx(IconArrowDown, null) }))));
});
function SampleTheme() {
    const theme = useTheme();
    return (jsx("div", { css: { background: theme.colors.palette.blue.base, padding: "3rem" } }));
}
function RefExample() {
    const ref = React.useRef();
    React.useEffect(() => {
        console.log(ref.current);
    }, []);
    return (jsx(DarkMode, { ref: ref },
        jsx(Button, null, "Hello")));
}
function ContrastExample() {
    const theme = useTheme();
    const dark = theme.colors.mode === "dark";
    return (jsx("div", { css: { display: "flex" } },
        jsx("div", { css: {
                height: "400px",
                flex: "1 1 30%",
                background: dark
                    ? theme.colors.background.layer
                    : theme.colors.background.tint1
            } },
            jsx(Text, null, "Hello")),
        jsx("div", { css: { flex: "1 1 70%" } }, "Basic")));
}
