/** @jsx jsx */
import { jsx } from "@emotion/react";
import * as React from "react";
import { Button } from "../Button";
import { storiesOf } from "@storybook/react";
import { Touchable } from "../Touchable";
import { useTouchable } from "touchable-hook";
import { Sheet } from "../Sheet";
function TouchableHighlight() {
    const [pressCount, setPressCount] = React.useState(0);
    function onPress() {
        console.log("Pressed!");
        setPressCount(pressCount + 1);
    }
    const { bind, active, hover } = useTouchable({
        onPress,
        behavior: "link"
    });
    return (jsx("div", null,
        pressCount,
        jsx("div", Object.assign({ role: "button", tabIndex: 0 }, bind, { css: {
                border: hover ? "1px solid black" : "1px solid transparent",
                userSelect: "none",
                outline: "none",
                background: active ? "#08e" : "transparent"
            } }), "This is a touchable highlight")));
}
export const TouchableStories = storiesOf("Touchable", module)
    .add("basic", () => {
    return (jsx("div", { css: { padding: "100px" } },
        jsx(TouchableHighlight, null),
        jsx("p", null, "Aute Lorem laboris nostrud culpa eiusmod in ipsum laborum. Minim cupidatat dolore tempor elit irure officia qui. Anim ea dolor excepteur eiusmod incididunt consectetur reprehenderit id. Incididunt tempor reprehenderit laboris eu exercitation voluptate proident nostrud eiusmod. Laborum consectetur culpa Lorem exercitation ut occaecat est proident labore ullamco id mollit. Labore reprehenderit commodo cupidatat mollit nostrud velit. Exercitation veniam consequat commodo aute incididunt anim duis incididunt sint officia veniam. Aliqua tempor ullamco in occaecat ullamco est ea aliqua exercitation amet cillum reprehenderit. Deserunt pariatur duis id dolore ut enim irure enim consectetur amet anim enim et. Elit Lorem veniam sit non magna esse.")));
})
    .add("embedded responders", () => {
    return jsx(SheetExample, null);
})
    .add("Touchable class", () => {
    return (jsx(Touchable, { css: {
            "&.Touchable--hover": {
                background: "#eee"
            },
            "&.Touchable--active": {
                background: "black"
            }
        } }, "Hello"));
});
function SheetExample() {
    const [open, setOpen] = React.useState(false);
    return (jsx("div", null,
        jsx(Button, { onPress: () => setOpen(true) }, "open"),
        jsx(Sheet, { position: "left", isOpen: open, onRequestClose: () => setOpen(false) },
            jsx(TouchableHighlight, null))));
}
